/*************************************************************************************
CPIS - 2.Construct CPIS Data

In this dofile we import the raw IMF data and clean it. We merge it with GDP and gravity control data

The raw data includes total holdings as well as disaggregated data for equity and debt. From this, we create three dtas: total assets, equity, and debt

Source: IMF CPIS. Bulk download. Format: Panel. Selected variables: Asset total investments BPM6 US dollars, Liabilities total investments BPM6 US dollars, Asset equity investments BPM6 US dollars, and Asset debt securities investments BPM6 US dollars. All countries. All Counterparty Countries. Sector: Total Holdings. Counterparty Sector: Total Holdings

*************************************************************************************/

import delimited "${CPIS}\CPIS_raw.csv", clear encoding("utf-8")
*This is the raw data downloaded from the IMF
global output_CPIS "${CPIS}\"
*Make sure data is from 2001 onwards
drop if timeperiod<2001
tab timeperiod, m

*We rename several variables to have them in the common format we use for all datasets
*Check variable names when updating data. Sometimes the raw IMF data has different variable names
rename countryname Acquiror
// rename ïcountryname Acquiror
rename counterpartcountryname Target
rename countrycode acq_code
rename counterpartcountrycode tgt_code
rename timeperiod year
rename assetstotalinvestmentbpm6usdolla value
label variable value "Total Assets in Current USD"
rename assetsequitybpm6usdollarsi_a_e_t value_equity
label variable value "Total Equity in Current USD"
rename assetsdebtsecuritiesbpm6usdollar value_debt
label variable value "Total Debt in Current USD"
drop counterpartsectorname counterpartsectorcode sectorname sectorcode status liabilitiestotalinvestmentbpm6us status v13 v15 v17 v18
*Very few countries report liabilities in CPIS. Thus, we cannot use liabilities to fill-in missing asset values (as we do for banking and FDI).

*Now we have to transform the country codes downloaded from the IMF to the ISO codes (3 digits).
kountry acq_code, from(imfn) to(iso3c)
rename _ISO3C_ acq
kountry tgt_code, from(imfn) to(iso3c)
rename _ISO3C_ tgt

*Fix countries without acq or tgt. Have to check each time data is updated as countries with problems can change
*Acquiror
replace acq ="CUW" if Acquiror =="Curacao & St. Maarten"
replace acq = "CUW" if Acquiror == "CuraÃ§ao and Sint Maarten"
replace acq = "CUW" if Acquiror == "Curaçao and Sint Maarten"
replace acq ="GGY" if Acquiror =="Guernsey"
replace acq ="IMN" if Acquiror =="Isle of Man"
replace acq ="JEY" if Acquiror =="Jersey"
replace acq="PSE" if Acquiror=="West Bank and Gaza"
replace acq ="XKX" if Acquiror =="Kosovo, Republic of"
replace acq ="XKX" if Acquiror =="Kosovo, Rep. of"

*Target
replace tgt ="AND" if Target =="Andorra"
replace tgt ="AND" if Target =="Andorra, Principality of"
replace tgt ="BES" if Target =="Bonaire, St. Eustatius and Saba"
replace tgt ="CXR" if Target =="Christmas Island"
replace tgt ="CCK" if Target =="Cocos (Keeling) Islands"
replace tgt ="CUW" if Target =="CuraÃ§ao, Kingdom of the Netherlands"
replace tgt ="ATF" if Target =="French Southern Territories"
replace tgt ="PRK" if Target =="Korea, Democratic People's Rep. of"
replace tgt ="PRK" if Target =="Korea, Dem. People's Rep. of"
replace tgt ="LIE" if Target =="Liechtenstein"
replace tgt ="MYT" if Target =="Mayotte"
replace tgt ="MCO" if Target =="Monaco"
replace tgt ="NIU" if Target =="Niue"
replace tgt ="NFK" if Target =="Norfolk Island"
replace tgt ="PCN" if Target =="Pitcairn Islands"
replace tgt ="PRI" if Target =="Puerto Rico"
replace tgt ="SRB" if Target =="Serbia, Republic of"
replace tgt ="SRB" if Target =="Serbia, Rep. of"
replace tgt ="SSD" if Target =="South Sudan"
replace tgt ="SSD" if Target =="South Sudan, Rep. of"
replace tgt ="TKL" if Target =="Tokelau Islands"
replace tgt ="TKL" if Target =="Tokelau"
replace tgt ="TCA" if Target =="Turks and Caicos Islands"
replace tgt ="TUV" if Target =="Tuvalu"
replace tgt ="VIR" if Target =="US Virgin Islands"
replace tgt ="VIR" if Target =="United States Virgin Islands"
replace tgt ="VGB" if Target =="Virgin Islands, British"
replace tgt ="VGB" if Target =="British Virgin Islands"
replace tgt ="WLF" if Target =="Wallis and Futuna"
replace tgt ="WLF" if Target =="Wallis and Futuna Islands"
replace tgt ="ESH" if Target =="Western Sahara"
replace tgt ="GGY" if Target =="Guernsey"
replace tgt ="IMN" if Target =="Isle of Man"
replace tgt ="JEY" if Target =="Jersey"
replace tgt ="XKX" if Target =="Kosovo, Republic of"
replace tgt ="XKX" if Target =="Kosovo, Rep. of"
replace tgt="CUW" if Target =="Curacao"
replace tgt="SXM" if Target=="Sint Maarten"
replace tgt="SXM" if Target=="Sint Maarten, Kingdom of the Netherlands"
replace tgt="PSE" if Target=="West Bank and Gaza"
replace tgt="CUW" if Target=="Curaçao, Kingdom of the Netherlands"
						      							
drop if tgt ==""
drop if acq ==""
//acq and tgt are missing for regions (e.g. Africa, US Pacific Islands, etc.) and very small countries that we don't include in our sample (e.g. the Vatican)

*Create country pair codes
gen country_dyad = acq+"_"+tgt
order acq tgt country_dyad year value Acquiror Target
sort acq tgt year
drop if acq == tgt
*We are just interested in capital flows across borders.

merge 1:1 country_dyad year using "$Country_Pairs\CountryPairs_2018.dta"  //We are merging with a perfect balanced matrix where we have all the possible counry pairs with all the years.
*The matrix has been expanded to include the year 2018.
drop Acquiror Target _merge acq_code tgt_code
drop if year<2001
sort acq tgt year

*Data are denominated in current USD, while the GDP is in millions of current USD. If we adjust the CPIS variables, then everything will be expressed in millions.
replace value=value/1000000
label variable value "Total Assets in Million Current USD"
replace value_equity=value_equity/1000000
label variable value "Total Equity in Million Current USD"
replace value_debt=value_debt/1000000
label variable value_debt "Total Debt in Million Current USD"

save "$output_CPIS\CPIS_temp.dta", replace

*We still have to add the gravity controls and the GDP.
use "$GDP\gdp.dta", clear
rename ISO acq
rename gdp gdp_acq
drop gdp_WB Country_WB Country_IMF gdp_IMF EstimatesStartAfter
save "$output_CPIS\auxx_1.dta", replace

use "$GDP\gdp.dta", clear
rename ISO tgt
rename gdp gdp_tgt
drop gdp_WB Country_WB Country_IMF gdp_IMF EstimatesStartAfter
save "$output_CPIS\auxx_2.dta", replace

clear all
use "$output_CPIS\CPIS_temp.dta", clear
merge m:1 acq year using "$output_CPIS\auxx_1.dta"
drop if _merge==2
*The unmatched observations that come from the using database appear because the GDP dataset contains information from 1990 to 2016, while the CPIS is from 2001 to 2015.
*The only country that comes from the "using" database and that we don't have in the rectangularized CPIS data is acq=="CHI" (Channel Islands).
drop _merge
merge m:1 tgt year using "$output_CPIS\auxx_2.dta"
drop if _merge==2
drop _merge
erase "$output_CPIS\auxx_1.dta"
erase "$output_CPIS\auxx_2.dta"

// *We also have to add the gravity controls, apart from the GDP.
// merge m:1 acq tgt using  "$GC\GC.dta"
//
// drop _merge
// label variable time "Time Difference" 
// label variable comlegal "Common Legal Origin"
// label variable cu  "Currency Union"
// label variable colony "Colony Relationship"
// label variable comlang "Common Language"
// label variable dist  "Distance"
// label variable border "Common Border"
// label variable d_lat "Difference in Latitude"
// label variable d_long "Difference in Longitude"

sort acq tgt year

*Save three different datasets: total, only equity, and only debt securities
preserve
drop value_equity value_debt
save "$input_databases\_CPIS.dta", replace
restore

preserve
drop value value_debt
rename value_equity value
*save "$output_CPIS\CPIS_equity_clean.dta", replace
*Input
compress
save "$input_databases\_CPIS_equity.dta", replace
restore

preserve
drop value value_equity
rename value_debt value
*save "$output_CPIS\CPIS_debt_clean.dta", replace
*Input
compress
save "$input_databases\_CPIS_debt.dta", replace
restore

erase "$output_CPIS\CPIS_temp.dta"
