/*************************************************************************************
CPIS - 3.Problem with zeros in 2004-05

For portfolio investment, when looking at the number of counterparts per source in AF2 we noticed a temporary surge in the number of counterparts reported in 2004 and 2005 (after 2005 values go back to normal)

In Figure 3 we see that for 2004 and 2005 the share of active links drop

Taken together, it seems that in 2004 and 2005 there is a lot of reporting zeros that then disappear

We confirm here that the presumption is true and proceed to eliminate the jump:
- When for a country-pair, there is a zero value in 2004 or 2005 but the values in 2003 and 2006 are missing, we change the zero to missing for 2004/2005

Note: We only correct this in the CPIS total data and not in the datasets that separate equity and debt
CPIS equity and CPIS debt data are only used in one table and we only show values (not active connections) so this is irrelevant
Also, we only show data for 2001, 2007, 2008, and 2016

For reference, I checked quickly and I did not see that CPIS equity and CPIS debt data have a jump in zeros in 2004 and 2005 so, in any case, the adjustement would not be needed

*************************************************************************************/

clear all
// set more off
// global output "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\4.CPIS\DTA"

use "$input_databases\_CPIS.dta" ,clear 

////////////////////////////////////////////////////////////////////////////////
/*Analysis of zeros in Portfolio Investment

*** Calculate the total number of non-missing reported per year, separating zeros and non-zeros

*Number of non-missing reported by country per year
bysort acq year: egen aux_nonmis= count(tgt) if value!=.
bysort acq year: egen nonmis=max(aux_nonmis)

*Number of zeros reported by country per year
bysort acq year: egen aux_zero= count(tgt) if value==0
bysort acq year: egen zero=max(aux_zero)

*Number of positive/negative reported by country per year
bysort acq year: egen aux_nonzero= count(tgt) if value!=0 & value!=.
bysort acq year: egen nonzero=max(aux_nonzero)

duplicates drop acq year, force

*Sum across countries per year
collapse (sum) nonmis zero nonzero, by(year)

*Ratio zeros / all non-missing
gen share_zero = zero / nonmis


Results:

In 2004 and 2005 there is a spike in the number of non-missing connections reported. This is driven by a rise in zeros

year	nonmis	zero	nonzero	share_zero
2001	8396	4873	3523	.5803954
2002	7879	4241	3638	.5382663
2003	8375	4515	3860	.5391045

2004	10537	6371	4166	.6046313
2005	16119	11591	4528	.7190893

2006	9707	4813	4894	.4958278
2007	9849	4726	5123	.4798457
2008	9896	4949	4947	.500101
2009	11511	6271	5240	.5447832
2010	12051	6601	5450	.5477554
2011	11459	5967	5492	.5207261
2012	11642	5897	5745	.5065281
2013	12097	6134	5963	.5070679
2014	12370	6095	6275	.4927243
2015	13361	6784	6577	.5077464
2016	13284	6581	6703	.495408
2017	13773	6921	6852	.5025049
2018	13671	6791	6880	.4967449

*** Calculate how many zeros in 2004 and 2005 are "new", that is, are missing before (2003) and after (2006) the spike
*Distinguish between cases when 2004 and 2005 is zero, only 2004 is zero, and only 2005 is zero

gen aux_value_2003=value if year==2003
gen aux_value_2006=value if year==2006
bysort acq tgt: egen value_2003=max(aux_value_2003)
bysort acq tgt: egen value_2006=max(aux_value_2006)
drop aux_value_2003 aux_value_2006

***For 2004***
*Identify all zeros
gen zero_2004=1 if year==2004 & value==0

*Identify new zeros
//A zero is new in 2004 if the value of 2004 and 2006 is missing
gen new_zero_2004=1 if zero_2004==1 & (value_2003==. & value_2006==.)

*Identify old zeros
//A zero is old in 2004 if the value of 2004 or 2006 is non-missing
gen old_zero_2004=1 if zero_2004==1 & (value_2003!=. | value_2006!=.)

***For 2005***
*Identify all zeros
gen zero_2005=1 if year==2005 & value==0

*Identify new zeros
//A zero is new in 2005 if the value of 2003 and 2006 is missing
gen new_zero_2005=1 if zero_2005==1 & (value_2003==. & value_2006==.)

*Identify old zeros
//A zero is old in 2004 if the value of 2004 or 2006 is non-missing
gen old_zero_2005=1 if zero_2005==1 & (value_2003!=. | value_2006!=.)

**Distinguish type of new zero
gen both_2004= 1 if  year==2004 & new_zero_2004==1 & new_zero_2005[_n+1]==1
gen only_2004= 1 if year==2004 & new_zero_2004==1 & new_zero_2005[_n+1]==.

gen both_2005= 1 if  year==2005 & new_zero_2005==1 & new_zero_2004[_n-1]==1
gen only_2005= 1 if year==2005 & new_zero_2005==1 & new_zero_2004[_n-1]==.

collapse (sum) zero_2004 new_zero_2004 old_zero_2004 zero_2005 new_zero_2005 old_zero_2005 both_2004 only_2004 both_2005 only_2005

Results: 
There are 6,371 zeros in 2004 of which 1,821 (29%) are missing in 2003 and 2006
There are 11,591 zeros in 2005 of which 5,478 (47%) are missing in 2003 and 2006

Of these 1,821 "new" zeros in 2004, 1,602 (88%) correspond to country-pairs where 2005 is also a "new" zero
Of these 5,478 "new" zeros in 2005, 1,602 (29%) correspond to country-pairs where 2004 is also a "new" zero

*/
//////////////////////////////////////////////////////////////////////////////////

*Removing jumps in 2004 and 2005 caused by zeros

gen aux_value_2003=value if year==2003
gen aux_value_2006=value if year==2006
bysort acq tgt: egen value_2003=max(aux_value_2003)
bysort acq tgt: egen value_2006=max(aux_value_2006)
drop aux_value_2003 aux_value_2006

***For 2004***
*Identify all zeros
gen zero_2004=1 if year==2004 & value==0

*Identify new zeros
//A zero is new in 2004 if the value of 2003 and 2006 is missing
gen new_zero_2004=1 if zero_2004==1 & value_2003==. & value_2006==.

***For 2005***
*Identify all zeros
gen zero_2005=1 if year==2005 & value==0

*Identify new zeros
//A zero is new in 2005 if the value of 2003 and 2006 is missing
gen new_zero_2005=1 if zero_2005==1 & value_2003==. & value_2006==.

replace value=. if new_zero_2004==1 | new_zero_2005==1

drop value_2003 value_2006 zero_2004 new_zero_2004 zero_2005 new_zero_2005

*save "$output_CPIS\CPIS_clean_2004-05zeros.dta", replace

compress
*Input
save "$input_databases\_CPIS.dta", replace
