
/***********************************************************************************************************************************************************************
UNCTAD spans from 2001-12 and IMF from 2009-18. We combine both datasets to obtain FDI data from 2001-18

The methodology we use is described below. Simply put, we use UNCTAD for 2001-08, IMF for 2013-18, and for 2009-12 we use a combination depending on the data available

Note that both databases are in different "levels". We decide to level UNCTAD to express it in IMF levels. We chose this rather than the alternative because IMF data is closer to Lane and Milessi-Ferretti, which is the benchmark

We also tried other alternatives on how to extrapolate missing values in one dataset using the growth rate of values in the other. But, we opted not to use these ones in the end

***********************************************************************************************************************************************************************/

clear all
// global input_UNCTAD "C:\Users\paolo\Dropbox\World Bank\Big Sur\JIE\1.Databases\5.FDI\FDI_UNCTAD\DTA"
// global input_IMF "C:\Users\paolo\Dropbox\World Bank\Big Sur\Stata\1.Databases\5.FDI\FDI_IMF\DTA"
// global pairs "C:\Users\paolo\Dropbox\World Bank\Big Sur\Stata\1.Databases\1.Country-Pairs"

*Combine UNCTAD and IMF data into a single file
***********************************************
use "${FDI_UN}\FDI_UNCTAD_clean.dta", clear
keep acq tgt country_dyad year value assets liabilities
rename (value assets liabilities) =_UNCTAD

merge 1:1 acq tgt year using "${FDI_IMF}\FDI_IMF_clean.dta"
//merge=2 for obs with years 2013 to 2016, which are not in the UNCTAD data
drop _merge
rename (value assets liabilities) =_IMF
sort acq tgt year

gen value=.
order value, b(value_UNCTAD)

// drop assets liabilities
save "${FDI_merge}\FDI_UNCTAD+IMF.dta", replace
erase "${FDI_IMF}\FDI_IMF_clean.dta"
erase "${FDI_UN}\FDI_UNCTAD_clean.dta"

*Define an unique VALUE variable
********************************
/*
Using both datasets, we create a VALUE variable that spans from 2001 to 2018
For 2001-2008, we only have UNCTAD
For 2009-2012, we can use UNCTAD or IMF
For 2013-2018, we only have IMF

So, we need to decide:
1. How to "adjust" the UNCTAD data so it is at the same level as the IMF data
2. We need to define criteria to decide, if for 2009-12 (when the two datasets overlap), we'll use IMF or UNCTAD values

We use the following criteria:

2001-2008:
**********
If for any year in 2009-12, IMF and UNCTAD have both a positive value in the same year: 
1. Calculate the ratio IMF value/UNCTAD value in that year and then multiply the UNCTAD data in 2001-08 by that ratio
2. If both datasets coincide in having a positive value for more than one year, we take the earlier year to calculate the ratio

If for no year in 2009-12 IMF and UNCTAD have both a positive value for a same year:
1. I do not level UNCTAD for 2001-08. Values for that period would stay as missing.

Note that I do not calculate the factor if one value is positive and the other one is negative, or both are negative. 
That could happen but it will be rare. I avoid this because it would give weird results when levelling the UNCTAD data (would change the signs of all the values)

2009-2012:
**********
We use a criterion to minimize the obs with zero or missing value

Start using the UNCTAD data and switch to IMF whenever the latter provides us with the same or more information than UNCTAD 
This means whenever:
1. IMF value is non-zero, non-missing, or
2. IMF value is zero and UNCTAD is missing

     e.g. |2009|2010|2011 
	   IMF|  0 |  3 |  5
	UNCTAD|  1 |  1 |  2
	Value |  3 |  3 |  5 //value in 2009 is UNCTAD value multiplied by ratio (3/1)
	 
	      e.g. |2009|2010|2011
	   IMF|  1 |  3 |  5
	UNCTAD|  0 |  1 |  2
	Value |  1 |  3 |  5

2013-2016:
**********
Value are always IMF values
*/

*Period: 2001-08
****************
*For each country pair, we want to know if in any year in 2009-12 IMF and UNCTAD data are both positive and which is the first year this happens
gen pos=1 if value_IMF!=. & value_IMF>0 & value_UNCTAD!=. & value_UNCTAD>0 & year<=2012 & year>=2009
bysort acq tgt: egen aux_first_year_pos=min(year) if pos==1
bysort acq tgt: egen first_year_pos=min(aux_first_year_pos)

*Obtain factor for levelling
gen aux_factor=value_IMF/value_UNCTAD if year==first_year_pos
bysort acq tgt: egen factor=min(aux_factor)

*Extrapolate values for 2001-08
replace value=value_UNCTAD*factor if year<=2008

drop pos aux_first_year_pos first_year_pos aux_factor

*Period: 2009-12
****************
*For each country pair, we want to know the first year in which IMF data provides equal or more information than UNCTAD data
*This means, IMF is non-missing, non-zero or IMF data is zero and UNCTAD data is missing
gen pos=1 if ((value_IMF!=. & value_IMF!=0) | (value_IMF==0 & value_UNCTAD==.)) & year<=2012 & year>=2009
bysort acq tgt: egen aux_first_year_pos=min(year) if pos==1
bysort acq tgt: egen first_year_pos=min(aux_first_year_pos)

*If for a country pair, pos is never equal to 1, this means UNCTAD data provides always better info than IMF for the entire 2009-12 period
*The first year for which IMF provides better data an UNCTAD is 2013
bysort acq tgt: replace first_year_pos=2013 if first_year_pos==.

*For a country pair the factor could be missing. In this case, we cannot use UNCTAD data (even if non-missing, non-zero) because we cannot level it to the IMF
*In these cases, we use IMF data for all 2009-12
replace value=value_IMF if year>=2009 & year<=2012 & factor==.

*When factor can be calculated:
*For years before first_year_pos, we use UNCTAD data
replace value=value_UNCTAD*factor if year>=2009 & year<=2012 & year<first_year_pos & factor!=.
*For first_year_pos and after, we use IMF data
replace value=value_IMF if year>=2009 & year<=2012 & year>=first_year_pos & factor!=.

drop factor pos aux_first_year_pos first_year_pos

*Period: 2013-16
****************
*For this period, data is always IMF data
replace value=value_IMF if year>=2013

merge 1:1 country_dyad year using "${Country_Pairs}\CountryPairs_2018.dta"  //We are merging with a perfect balanced matrix where we have all the possible counry pairs with all the years.
*The matrix has been expanded to include the year 2018.
drop _merge
drop if year<2001
sort acq tgt year

*save "${FDI_merge}\FDI_UNCTAD+IMF_clean.dta", replace

*Treating Missing Values
************************
/*
When we run regressions using "FDI_cleaned_miss", we have negative coefficients, which is strange
We notice this issue arises because, the way the data is constructed, it has a lot of zeros in the later years but in the earlier years many zeros appeared as missing
This gives the impression that values are falling over time and produce negative coefficients

This occurs for two reasons:

1. Countries tend to report more zeros to IMF than to UNCTAD

Count zeros and missings in each dataset:
- UNCTAD
count if year<=2012 // 753,000
count if value_UNCTAD==0 & year<=2012 // 26,682 (4%)
count if value_UNCTAD==. & year<=2012 // 672,701 (89%)

- IMF
count if year>=2009 // 627,500
count if value_IMF==0 & year>=2009 // 80,990 (13%)
count if value_IMF==. & year>=2009 // 466,330 (74%)

2. When we cannot calculate the factor, we are not obtaining values for 2001-08. So, many zeros from UNCTAD are being "lost"

Thus, we need a criterion to "create" zeros at the beginning of the sample
*/

*Criteria we use: 
*****************
*If for a country-pair the first non-missing obs is a zero, we assume all previous obs are also zero

*For each country pair, we identify first non-missing obs and year in which occurs
gen aux_non_miss=1 if value!=.
bysort acq tgt: egen aux_first_year=min(year) if aux_non_miss==1
bysort acq tgt: egen first_year=min(aux_first_year)

bysort acq tgt: gen aux_first_non_miss=value if year==first_year
bysort acq tgt: egen first_non_miss=min(aux_first_non_miss)

drop aux_non_miss aux_first_year aux_first_non_miss

replace value=0 if first_non_miss==0 & year<first_year

drop first_year first_non_miss

*save "${FDI_merge}\FDI_UNCTAD+IMF_clean_zeros.dta", replace

compress
* Input
save "${input_databases}\_FDI.dta", replace

/*

ALTERNATIVE CRITERIA WE TRIED BUT OPTED NOT TO USE

**Option 1**
*If a country pair has at least one zero and the rest are missing obs, we assume all values are zero for all years
*If all values are missing, then we keep all obs as missing

use "$output\FDI_cleaned_miss.dta", clear

bysort acq tgt: egen aux_min=min(value)
bysort acq tgt: egen aux_max=max(value)
*If aux_min=0 and aux_max=0, for that country pair we only have zero values (there could be missing but at least one obs is zero) 
*In this case, we assume all values are zero for all years
replace value=0 if aux_min==0 & aux_max==0

drop aux_min aux_max

save "$output\FDI_cleaned_alt1.dta", replace

**Option 2**
*Same criterion as before but now only values in 2001-08 are assumed to be zero

use "$output\FDI_cleaned_miss.dta", clear

bysort acq tgt: egen aux_min=min(value)
bysort acq tgt: egen aux_max=max(value)

*If aux_min=0 and aux_max=0, for that country pair we only have zero values. 
*We assume all values before 2009 are zero
*In contrast to the previous option, we keep the missing of the IMF data
replace value=0 if year<2009 & aux_min==0 & aux_max==0

drop aux_min aux_max

save "$output\_FDI_cleaned_alt2.dta", replace

/*


/*We also tried different criteria to combine the datasets


*Alternative 1: UNCTAD data and extrapolate values for 2013-16 using IMF's data growth rates
********************************************************************************************
*VALUE is equal to VALUE_UNCTAD. 
*We use the following criteria to fill-in values for the years 2013-16:
*1)We calculate the annual growth rate of VALUE_IMF for the years 2013-16.
*2)We assume that VALUE_UNCTAD had the same growth rate as VALUE_IMF

*We need to be careful with the signs of the variables because otherwise the percentage changes would not be computed in the direction we need.
*For example, if VALUE_IMF in t and t+1 are both positive and increase over time and, also, VALUE_UNCTAD is positive, we want VALUE_UNCTAD to increase in absolute value
*In contrast, if VALUE_UNCTAD is negative, we it assets to decrease in absolute value (become less negative)

use "$output\FDI_UNCTAD+IMF.dta", clear

replace value=value_UNCTAD

*Identify obs in 2013 that can be extrapolated
*These are obs for which we have a VALUE_UNCTAD for 2012 and we have VALUE_IMF for 2012 and 2013 
gen extra=1 if year==2013 & value_UNCTAD[_n-1]!=. & value_UNCTAD[_n-1]!=0 & value_IMF[_n-1]!=. & value_IMF[_n-1]!=0 & value_IMF!=. & value_IMF!=0 
//I add the condition that values have to be different from zero because otherwise we cannot make any extrapolation

*Once we extrapolate the obs for 2013, we can use this value to extrapolate the value for 2014 and so on
*We can do this for obs for which we can extrapolate the value for the previous year and we have VALUE_IMF for that year   
forvalues i=1/3 {
bysort acq tgt: replace extra=1 if extra[_n-1]==1 & value_IMF!=. & value_IMF!=0
}
//I run it 3 times (2014, 2015, and 2016)

*Identify cases in which values are always positive so we don't have the problem of the signs
gen extra_pos=1 if year==2013 & value_UNCTAD[_n-1]!=. & value_UNCTAD[_n-1]>0 & value_IMF[_n-1]!=. & value_IMF[_n-1]>0 & value_IMF!=. & value_IMF>0 

*Again, we need to consider values that we can extrapolate once we extrapolated the previous values
*In this case, if extra_pos is 1, the extrapolated value in t+1 will be positive. But we still need the condition that value_IMF is positive
forvalues i=1/3 {
bysort acq tgt: replace extra_pos=1 if extra_pos[_n-1]==1 & value_IMF!=. & value_IMF>0
}

replace extra=0 if extra==.
replace extra_pos=0 if extra_pos==.

*tab extra extra_pos
*Of 9,541 possible extrapolated values, 8,881 correspond to cases in which values) are positive so we don't have to care about the sign problem
*As a first version, we extrapolate only those cases and leave the others as missing. Later on we need to decide a criteria for the other cases

*Calculate growth rate of VALUE_IMF
bysort acq tgt: gen IMF_rate=value_IMF/value_IMF[_n-1]

*Extrapolate values using the growth rate of VALUE_IMF
bysort acq tgt: replace value=value[_n-1]*IMF_rate if extra_pos==1

forvalues i=1/3 {
bysort acq tgt: replace value=value[_n-1]*IMF_rate if extra_pos==1
}

drop value_UNCTAD value_IMF assets liabilities extra extra_pos IMF_rate

save "$output\FDI_cleaned_alt1.dta", replace

*Alternative 2: IMF data and extrapolate values for 2001-08 using UNCTAD's data growth rates
********************************************************************************************
*VALUE is equal to VALUE_IMF. 
*We use the following criteria to fill-in values for the years 2001-08:
*1)We calculate the annual growth rate of VALUE_UNCTAD for the years 2001-08.
*2)We assume that VALUE_IMF had the same growth rate as VALUE_UNCTAD

*We need to be careful with the signs of the variables because otherwise the percentage changes would not be computed in the direction we need.
*For example, if VALUE_UNCTAD in t and t+1 are both positive and increase over time and, also, VALUE_IMF is positive, we want VALUE_UNCTAD to increase in absolute value
*In contrast, if VALUE_IMF is negative, we it assets to decrease in absolute value (become less negative)

use "$output\FDI_UNCTAD+IMF.dta", clear

replace value=value_IMF

*Identify obs in 2008 that can be extrapolated
*These are obs for which we have a VALUE_IMF for 2009 and we have VALUE_UNCTAD for 2008 and 2009 
gen extra=1 if year==2008 & value_IMF[_n+1]!=. & value_IMF[_n+1]!=0 & value_UNCTAD[_n+1]!=. & value_UNCTAD[_n+1]!=0 & value_UNCTAD!=. & value_UNCTAD!=0 
//I add the condition that values have to be different from zero because otherwise we cannot make any extrapolation

*Once we extrapolate the obs for 2008, we can use this value to extrapolate the value for 2007, 2006 and so on
*We can do this for obs for which we can extrapolate the value for the next year and we have VALUE_UNCTAD for that year   
forvalues i=1/8 {
bysort acq tgt: replace extra=1 if extra[_n+1]==1 & value_UNCTAD!=. & value_UNCTAD!=0
}
//I run it 8 times (2001-08)

*Identify cases in which values are always positive so we don't have the problem of the signs
gen extra_pos=1 if year==2008 & value_IMF[_n+1]!=. & value_IMF[_n+1]>0 & value_UNCTAD[_n+1]!=. & value_UNCTAD[_n+1]>0 & value_UNCTAD!=. & value_UNCTAD>0 

*Again, we need to consider values that we can extrapolate once we extrapolated the previous values
*In this case, if extra_pos is 1, the extrapolated value in t+1 will be positive. But we still need the condition that value_IMF is positive
forvalues i=1/8 {
bysort acq tgt: replace extra_pos=1 if extra_pos[_n+1]==1 & value_UNCTAD!=. & value_UNCTAD>0
}

replace extra=0 if extra==.
replace extra_pos=0 if extra_pos==.

*tab extra extra_pos
*Of 12,896 possible extrapolated values, 12,395 correspond to cases in which values are positive so we don't have to care about the sign problem
*As a first version, we extrapolate only those cases and leave the others as missing. Later on we need to decide a criteria for the other cases

*Calculate growth rate of VALUE_IMF
bysort acq tgt: gen UNCTAD_rate=value_UNCTAD[_n+1]/value_UNCTAD

*Extrapolate values using the growth rate of VALUE_IMF
bysort acq tgt: replace value=value[_n+1]/UNCTAD_rate if extra_pos==1

forvalues i=1/8 {
bysort acq tgt: replace value=value[_n+1]/UNCTAD_rate if extra_pos==1
}

drop value_UNCTAD value_IMF assets liabilities extra extra_pos UNCTAD_rate

save "$output\FDI_cleaned_alt2.dta", replace
