/**********************************************************************************************************
1. IR - Clean

This file cleans the data on international reserves

This dataset is different from the others. We don't have country-country data, but only data on total reserves by country. 

Making some assumptions we can construct a country-region data:
1. We have data on the yearly currency composition of reserves by advanced and emerging economies, separately
2. We can obtain the annual shares N and S hold in currencies of N and S countries
3. We use these shares to calculate the value of reserves held in the North and South for each country

See file "CurrencyCompositionReserves" for more details on how the shares are calculated

Source:
- Reserve assets: IMF, IFS. Format: Panel. Variable: International Liquidity, Total Reserves excluding Gold, US Dollars (RAXG_USD). All countries.


***********************************************************************************************************/

***** Clean data ***** 
**********************
import delimited "${IR}\IR_raw.csv", clear encoding("utf-8")

global output_IR "${IR}"
// global pairs "C:\Users\paolo\Dropbox\World Bank\Big Sur\Stata\1.Databases\1.Country-Pairs"
// global gdp "C:\Users\paolo\Dropbox\World Bank\Big Sur\Stata\1.Databases\2.GDP\DTA"

tab timeperiod, m
keep if inrange(timeperiod,2001,2018)

*We rename several variables to have them in the common format we use for all datasets
*Check variable names when updating data. Sometimes the raw IMF data has different variable names

rename countryname Acquiror
// rename ïcountryname Acquiror
rename countrycode acq_code
rename timeperiod year
rename internationalliquiditytotalreser value_res
label variable value_res "Total Int Reserves excl. Gold in Current USD"
drop status v6

sort acq year


*Now we have to transform the country codes downloaded from the IMF to the ISO codes (3 digits).
kountry acq_code, from(imfn) to(iso3c)
rename _ISO3C_ acq

*Fix countries without acq. Have to check each time data is updated as countries with problems can change
*Acquiror
replace acq ="CUW" if Acquiror =="Curacao & St. Maarten"
replace acq ="CUW" if Acquiror =="Curaçao and Sint Maarten"
replace acq = "CUW" if Acquiror == "CuraÃ§ao and Sint Maarten"
*"Curaçao, Kingdom of the Netherlands" is duplicated with Curacao and Sint Marteen and has all missing. We just drop it
replace acq ="GGY" if Acquiror =="Guernsey"
replace acq ="IMN" if Acquiror =="Isle of Man"
replace acq ="JEY" if Acquiror =="Jersey"
replace acq="PSE" if Acquiror=="West Bank and Gaza"
replace acq ="XKX" if Acquiror =="Kosovo, Republic of"
replace acq ="XKX" if Acquiror =="Kosovo, Rep. of"
replace acq ="SRB" if Acquiror =="Serbia, Rep. of"
replace acq="SXM" if Acquiror=="Sint Maarten, Kingdom of the Netherlands"
replace acq ="SSD" if Acquiror =="South Sudan, Rep. of"
replace acq ="TCA" if Acquiror =="Turks and Caicos Islands"
replace acq ="TUV" if Acquiror =="Tuvalu"
							      							
drop if acq =="" //acq are missing for regions (e.g. Africa, US Pacific Islands, etc.) and very small countries that we don't include in our sample (e.g. Western Bank and Gaza)

drop Acquiror acq_code
order acq year value_res
sort acq year

save "$output_IR\IR_C-World_clean.dta", replace

*We want to fill in all the countries and years in our sample with missing values
*We can do this by using the country-pairs list. But, for reserves, we don't need country-pairs but only sender country data
use "${Country_Pairs}\CountryPairs_2018.dta", clear  //We are loading a perfect balanced matrix where we have all the possible country pairs with all the years.
keep acq year
duplicates drop acq year, force //We have a list of countries and year in our sample
save "$output_IR\aux1.dta", replace

use "$output_IR\IR_C-World_clean.dta", clear
merge 1:1 acq year using "$output_IR\aux1.dta"
drop _merge //_merge is never 1, so the IR data doesn't have any country that it is not in our sample
keep if year >=2001
sort acq year


*For each country we want two obs per year: reserves held in the North and the South
expand = 2
bysort acq year: gen tgt="North" if _n==1
bysort acq year: replace tgt="South" if _n==2

*Data are denominated in current USD, we change it to millions
replace value_res=value_res/1000000
label variable value_res "Total Int Reserves excl. Gold in Million USD"

*Classify countries into regions
gen n1_acq =0
replace n1_acq=1 if acq=="AND" |acq=="AUT" |acq=="BEL" |acq=="CAN" |acq=="DNK" |acq=="FIN" |acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="ISL" |acq=="IRL" |acq=="ITA" |acq=="JPN" |acq=="LIE" |acq=="LUX" |acq=="MCO" | ///
acq=="NLD" |acq=="NOR" |acq=="PRT" |acq=="SMR" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="GBR" |acq=="USA" 

* Additional countries in North based on BIS classification (including OFCs) 
	replace n1_acq=1 if inlist(acq,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_acq=1 if inlist(acq,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_acq=1 if inlist(acq,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_acq=1 if inlist(acq,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")

	* Note that the additional North countries include reallocated OFCs. 
	* If we want to continue excluding OFCs, we can run the script below unchanged. 
	

*Offshore Centers (25)			<--- UNCHANGED
**********************
g OFC_acq = 0
replace OFC_acq =1  if acq=="AND" | acq=="AIA" | acq=="ABW" | acq=="BHS" | acq=="BLZ" | acq=="BMU" | acq=="VGB" | acq=="CYM" | acq=="COK" | acq=="CYP" | acq=="GIB" | acq=="GGY" | acq=="IMN" | acq=="JEY" | ///
acq=="LIE" | acq=="MAC" | acq=="MCO" | acq=="MSR" | acq=="ANT" | acq=="PLW" | acq=="PAN" | acq=="WSM" | acq=="SYC" | acq=="TCA" | acq=="VUT" 


replace n1_acq =0 if OFC_acq ==1

gen s1_acq=0
replace s1_acq=1 if n1_acq==0 & OFC_acq==0

gen n1_tgt=0
replace n1_tgt=1 if tgt=="North"

gen s1_tgt=0
replace s1_tgt=1 if tgt=="South"

*We don't have data on holdings of int reserves per country in each region
*But, we do have data on currency compositions of reserves in advanced and emerging regions
*We use the share of each region's reserves in each currency to assign the reserves of each country to each region
*For the detail on how we obtain these shares, see the file "CurrencyCompositionReserves"
*Note: the currency composition per region for 2015-18 is not available. So, we assume for those years the same share as in 2014

gen share=.

//Share of North countries' reserves held in North and South
replace share=0.986 if n1_acq==1 & tgt=="North" & year==2001
replace share=0.014 if n1_acq==1 & tgt=="South" & year==2001
replace share=0.984 if n1_acq==1 & tgt=="North" & year==2002
replace share=0.016 if n1_acq==1 & tgt=="South" & year==2002
replace share=0.979 if n1_acq==1 & tgt=="North" & year==2003
replace share=0.021 if n1_acq==1 & tgt=="South" & year==2003
replace share=0.979 if n1_acq==1 & tgt=="North" & year==2004
replace share=0.021 if n1_acq==1 & tgt=="South" & year==2004
replace share=0.98 if n1_acq==1 & tgt=="North" & year==2005
replace share=0.02 if n1_acq==1 & tgt=="South" & year==2005
replace share=0.979 if n1_acq==1 & tgt=="North" & year==2006
replace share=0.021 if n1_acq==1 & tgt=="South" & year==2006
replace share=0.976 if n1_acq==1 & tgt=="North" & year==2007
replace share=0.024 if n1_acq==1 & tgt=="South" & year==2007
replace share=0.973 if n1_acq==1 & tgt=="North" & year==2008
replace share=0.027 if n1_acq==1 & tgt=="South" & year==2008
replace share=0.971 if n1_acq==1 & tgt=="North" & year==2009
replace share=0.029 if n1_acq==1 & tgt=="South" & year==2009
replace share=0.957 if n1_acq==1 & tgt=="North" & year==2010
replace share=0.043 if n1_acq==1 & tgt=="South" & year==2010
replace share=0.953 if n1_acq==1 & tgt=="North" & year==2011
replace share=0.047 if n1_acq==1 & tgt=="South" & year==2011
replace share=0.970 if n1_acq==1 & tgt=="North" & year==2012
replace share=0.030 if n1_acq==1 & tgt=="South" & year==2012
replace share=0.975 if n1_acq==1 & tgt=="North" & year==2013
replace share=0.025 if n1_acq==1 & tgt=="South" & year==2013
replace share=0.973 if n1_acq==1 & tgt=="North" & year==2014
replace share=0.027 if n1_acq==1 & tgt=="South" & year==2014
replace share=0.973 if n1_acq==1 & tgt=="North" & year==2015
replace share=0.027 if n1_acq==1 & tgt=="South" & year==2015
replace share=0.973 if n1_acq==1 & tgt=="North" & year==2016
replace share=0.027 if n1_acq==1 & tgt=="South" & year==2016
replace share=0.973 if n1_acq==1 & tgt=="North" & year==2017
replace share=0.027 if n1_acq==1 & tgt=="South" & year==2017
replace share=0.973 if n1_acq==1 & tgt=="North" & year==2018
replace share=0.027 if n1_acq==1 & tgt=="South" & year==2018

//Share of South countries' reserves held in North and South and Share of OFCs' reserves held in North and South (assumption: same shares as South countries since IMF's list of advanced economies excludes most of OFCs)

foreach x in s1_acq OFC_acq{
	replace share=0.989 if `x'==1 & tgt=="North" & year==2001
	replace share=0.011 if `x'==1 & tgt=="South" & year==2001
	replace share=0.986 if `x'==1 & tgt=="North" & year==2002
	replace share=0.014 if `x'==1 & tgt=="South" & year==2002
	replace share=0.982 if `x'==1 & tgt=="North" & year==2003
	replace share=0.018 if `x'==1 & tgt=="South" & year==2003
	replace share=0.988 if `x'==1 & tgt=="North" & year==2004
	replace share=0.012 if `x'==1 & tgt=="South" & year==2004
	replace share=0.987 if `x'==1 & tgt=="North" & year==2005
	replace share=0.013 if `x'==1 & tgt=="South" & year==2005
	replace share=0.986 if `x'==1 & tgt=="North" & year==2006
	replace share=0.014 if `x'==1 & tgt=="South" & year==2006
	replace share=0.987 if `x'==1 & tgt=="North" & year==2007
	replace share=0.013 if `x'==1 & tgt=="South" & year==2007
	replace share=0.984 if `x'==1 & tgt=="North" & year==2008
	replace share=0.016 if `x'==1 & tgt=="South" & year==2008
	replace share=0.971 if `x'==1 & tgt=="North" & year==2009
	replace share=0.029 if `x'==1 & tgt=="South" & year==2009
	replace share=0.957 if `x'==1 & tgt=="North" & year==2010
	replace share=0.043 if `x'==1 & tgt=="South" & year==2010
	replace share=0.939 if `x'==1 & tgt=="North" & year==2011
	replace share=0.061 if `x'==1 & tgt=="South" & year==2011
	replace share=0.965 if `x'==1 & tgt=="North" & year==2012
	replace share=0.035 if `x'==1 & tgt=="South" & year==2012
	replace share=0.969 if `x'==1 & tgt=="North" & year==2013
	replace share=0.031 if `x'==1 & tgt=="South" & year==2013
	replace share=0.971 if `x'==1 & tgt=="North" & year==2014
	replace share=0.029 if `x'==1 & tgt=="South" & year==2014
	replace share=0.971 if `x'==1 & tgt=="North" & year==2015
	replace share=0.029 if `x'==1 & tgt=="South" & year==2015
	replace share=0.971 if `x'==1 & tgt=="North" & year==2016
	replace share=0.029 if `x'==1 & tgt=="South" & year==2016
	replace share=0.971 if `x'==1 & tgt=="North" & year==2017
	replace share=0.029 if `x'==1 & tgt=="South" & year==2017
	replace share=0.971 if `x'==1 & tgt=="North" & year==2018
	replace share=0.029 if `x'==1 & tgt=="South" & year==2018	
}

gen value=share*value_res

label variable value "Total Int Reserves excl. Gold in Million USD"
 
drop value_res share

order acq tgt year value n1_acq OFC_acq s1_acq n1_tgt s1_tgt

save "$output_IR\IR_C-R_clean.dta", replace

*We still have to add the GDP.
use "${GDP}\gdp.dta", clear
rename ISO acq
rename gdp gdp_acq
drop gdp_WB Country_WB Country_IMF gdp_IMF EstimatesStartAfter
save "$output_IR\auxx_1.dta", replace

use "$output_IR\IR_C-R_clean.dta", clear
merge m:1 acq year using "$output_IR\auxx_1.dta"
drop if _merge==2
drop _merge
save "$output_IR\IR_C-R_clean.dta", replace

* (not necessary) I introduce a sleep because the code runs very fast and cannot erase the database.
sleep 5000

erase "$output_IR\auxx_1.dta"
erase "$output_IR\aux1.dta" 

compress
* Input
save "${input_databases}\_IR.dta", replace
