/*
2. GDP - Region Level

********
Before running this file, make sure the databases are updated and saved in the "Input" folder
*********

In this file we aggregate the GDP by regions.

However, we will have one GDP for the region being a sender and a different one for the region being a receiver.
We will also have different GDPs depending on the database being used, even if we are referring to the same region.

These differences come from the fact that we only want to use the GDP of the countries for which we have financial information.
We don't want to divide by the GDP of countries that we are not including when we sum the investments (we only want the reporting countries)

*/

clear all
set more off

global output_GDP "${GDP}\"

**********************************************************************************************
*First, we calculate GDP's for CPIS and FDI datasets
*GDP's for IR is calculated separately because the format of the data is different
**********************************************************************************************

*First, we obtain a list of reporting countries (senders and receivers separately) for each database
* NOTE: If hoy have access to IBS data, change the "4" to "5"
forvalues i=1/4 {

if `i' ==1 { 
use "$input_databases\_CPIS.dta",clear
local database ="CPIS"
}

if `i' ==2 { 
use "$input_databases\_CPIS_equity.dta",clear
local database ="CPIS_equity"
}

if `i' ==3 { 
use "$input_databases\_CPIS_debt.dta",clear
local database ="CPIS_debt"
}

if `i' ==4 { 
use "$input_databases\_FDI.dta",clear 
local database ="FDI"
}

// if `i' ==5 { 
// use "$input_databases\_IBS.dta",clear 
// local database ="IBS"



preserve
bysort acq year: egen total=sum(value), missing
duplicates drop acq year total, force
gen reporting=0
replace reporting=1 if total!=.
*We assign a 1 to the observations that are either 0 or positive, because we want to know which countries are reporting.
keep acq year reporting
save "$output_GDP\Reporting\reporting_sender_`database'.dta", replace

restore

bysort tgt year: egen total=sum(value), missing
duplicates drop tgt year total, force
gen reporting=0
replace reporting=1 if total!=.
keep tgt year reporting
save "$output_GDP\Reporting\reporting_receiver_`database'.dta", replace
}

*Once we have the list of reporting countries, both senders and receivers, for all the databases, we have to merge them with the GDP files. 
*We make this step to identify which countries have to be used to aggregate the GDPs (which are the reporters).

use "$output_GDP\gdp.dta",clear 

*Notice that the GDP has not been deflated.

keep ISO year gdp

// local databases "CPIS CPIS_equity CPIS_debt FDI IBS" // If you have access to Banking database, uncomment this.
local databases "CPIS CPIS_equity CPIS_debt FDI"
	
	
foreach x of local databases {
preserve
rename ISO acq
merge 1:1 acq year using "$output_GDP\Reporting\reporting_sender_`x'.dta"
keep if _merge==3
drop _merge
	
gen n1_acq = 0
replace n1_acq=1 if acq=="AND" |acq=="AUT" |acq=="BEL" |acq=="CAN" |acq=="DNK" |acq=="FIN" |acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="ISL" |acq=="IRL" |acq=="ITA" |acq=="JPN" |acq=="LIE" |acq=="LUX" |acq=="MCO" | ///
acq=="NLD" |acq=="NOR" |acq=="PRT" |acq=="SMR" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="GBR" |acq=="USA" 

* Additional countries in North based on BIS classification (including OFCs) 
	replace n1_acq=1 if inlist(acq,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_acq=1 if inlist(acq,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_acq=1 if inlist(acq,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_acq=1 if inlist(acq,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")

gen OFC_acq = 0
replace OFC_acq =1  if acq=="AND" | acq=="AIA" | acq=="ABW" | acq=="BHS" | acq=="BLZ" | acq=="BMU" | acq=="VGB" | acq=="CYM" | acq=="COK" | acq=="CYP" | acq=="GIB" | acq=="GGY" | acq=="IMN" | acq=="JEY" | ///
acq=="LIE" | acq=="MAC" | acq=="MCO" | acq=="MSR" | acq=="ANT" | acq=="PLW" | acq=="PAN" | acq=="WSM" | acq=="SYC" | acq=="TCA" | acq=="VUT"

replace n1_acq =0 if OFC_acq ==1
// replace OFC_acq = 0	// safer, so that drops don't take effect.

gen s1_acq=0
replace s1_acq=1 if n1_acq==0 & OFC_acq==0

gen richest20_acq=0
replace richest20_acq=1 if acq =="QAT" | acq=="AUS" | acq=="SGP" | acq=="NZL" | acq=="KWT" | acq=="ARE" | acq=="BRN" | acq=="HKG" | acq=="ISR" | acq=="KOR" | /// 
						   acq =="BHR" | acq=="MLT" | acq=="SAU" | acq=="SVN" | acq=="TWN" | acq=="SVK" | acq=="BHS" | acq=="EST" | acq=="LTU" | acq=="CZE"
/* Ranking based on IMF GDP per capita at current USD. In the 2020 update, this list was updated based using values for 2018. Barbados and Oman were replaced by Bahamas and Lithuania*/
	
bysort year: egen north_S_`x'= sum(gdp) if n1_acq==1 & reporting==1
bysort year: egen south_S_`x'= sum(gdp) if s1_acq==1 & reporting==1
bysort year: egen OFC_S_`x'= sum(gdp) if OFC_acq==1 & reporting==1
bysort year: egen world_S_`x'= sum(gdp) if (n1_acq==1 | s1_acq==1) & reporting==1
bysort year: egen china_S_`x'=sum(gdp) if acq=="CHN" & reporting==1
bysort year: egen richest20_S_`x'=sum(gdp) if richest20_acq==1 & reporting==1
bysort year: egen world_OFC_S_`x' = sum(gdp) if (n1_acq==1 | s1_acq==1 | OFC_acq == 1) & reporting == 1
	
collapse (max) north_S_`x'-richest20_S_`x', by(year)

save "$output_GDP\gdp_sender_`x'.dta", replace
restore
}


foreach x of local databases {
preserve
rename ISO tgt
merge 1:1 tgt year using "$output_GDP\Reporting\reporting_receiver_`x'.dta"
keep if _merge==3
drop _merge

gen n1_tgt = 0
replace n1_tgt=1 if tgt=="AND" |tgt=="AUT" |tgt=="BEL" |tgt=="CAN" |tgt=="DNK" |tgt=="FIN" |tgt=="FRA" |tgt=="DEU" |tgt=="GRC" |tgt=="ISL" |tgt=="IRL" |tgt=="ITA" |tgt=="JPN" |tgt=="LIE" |tgt=="LUX" |tgt=="MCO" | ///
tgt=="NLD" |tgt=="NOR" |tgt=="PRT" |tgt=="SMR" |tgt=="ESP" |tgt=="SWE" |tgt=="CHE" |tgt=="GBR" |tgt=="USA" 

* Same for target: Additional countries in North based on BIS classification (including OFCs) 
	replace n1_tgt=1 if inlist(tgt,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_tgt=1 if inlist(tgt,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_tgt=1 if inlist(tgt,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_tgt=1 if inlist(tgt,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")

gen OFC_tgt = 0
replace OFC_tgt =1  if tgt=="AND" | tgt=="AIA" | tgt=="ABW" | tgt=="BHS" | tgt=="BLZ" | tgt=="BMU" | tgt=="VGB" | tgt=="CYM" | tgt=="COK" | tgt=="CYP" | tgt=="GIB" | tgt=="GGY" | tgt=="IMN" | tgt=="JEY" | ///
tgt=="LIE" | tgt=="MAC" | tgt=="MCO" | tgt=="MSR" | tgt=="ANT" | tgt=="PLW" | tgt=="PAN" | tgt=="WSM" | tgt=="SYC" | tgt=="TCA" | tgt=="VUT"

// replace OFC_tgt = 0

 replace n1_tgt =0 if OFC_tgt ==1

g s1_tgt=0
replace s1_tgt=1 if n1_tgt==0  & OFC_tgt==0	

gen richest20_tgt=0
replace richest20_tgt=1 if tgt =="QAT" | tgt=="AUS" | tgt=="SGP" | tgt=="NZL" | tgt=="KWT" | tgt=="ARE" | tgt=="BRN" | tgt=="HKG" | tgt=="ISR" | tgt=="KOR" | /// 
						   tgt =="BHR" | tgt=="MLT" | tgt=="SAU" | tgt=="SVN" | tgt=="TWN" | tgt=="SVK" | tgt=="BHS" | tgt=="EST" | tgt=="LTU" | tgt=="CZE"
	
bysort year: egen north_R_`x'= sum(gdp) if n1_tgt==1 & reporting==1
bysort year: egen south_R_`x'= sum(gdp) if s1_tgt==1 & reporting==1
bysort year: egen OFC_R_`x'= sum(gdp) if OFC_tgt==1 & reporting==1
bysort year: egen world_R_`x'= sum(gdp) if (n1_tgt==1 | s1_tgt==1) & reporting==1
bysort year: egen china_R_`x'=sum(gdp) if tgt=="CHN" & reporting==1
bysort year: egen richest20_R_`x'=sum(gdp) if richest20_tgt==1 & reporting==1
bysort year: egen world_OFC_R_`x' = sum(gdp) if (n1_tgt==1 | s1_tgt==1 | OFC_tgt == 1) & reporting == 1
		
collapse (max) north_R_`x'-richest20_R_`x', by(year)

save "$output_GDP\gdp_receiver_`x'.dta", replace
restore
}
	
use "$output_GDP\gdp_sender_CPIS.dta", clear
// local databases_2 "CPIS_equity CPIS_debt FDI IBS" // If you have access to Banking database, uncomment this.
local databases_2 "CPIS_equity CPIS_debt FDI"
foreach z of local databases_2 {
merge 1:1 year using "$output_GDP\gdp_sender_`z'.dta"
drop _merge
}

// local databases_3 "CPIS CPIS_equity CPIS_debt FDI IBS" // If you have access to Banking database, uncomment this.
local databases_3 "CPIS CPIS_equity CPIS_debt FDI"
foreach y of local databases_3 {
merge 1:1 year using "$output_GDP\gdp_receiver_`y'.dta"
drop _merge
}

*Now we have a Regions_GDP file where each column reports the value of the corresponding region GDP for a given database. 

foreach y of local databases_3 {
label variable south_S_`y' "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable north_S_`y' "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable OFC_S_`y' "Data in Million of Current USD (Sender)"
label variable world_S_`y' "Excluding OFCs-Data in Million of Current USD (Sender)"
label variable china_S_`y' "Data in Million of Current USD (Sender)"
label variable richest20_S_`y' "Excluding OFCs-Data in Million of Current USD (Sender)"

label variable south_R_`y' "Excluding OFCs- Data in Million of Current USD (Receiver)"
label variable north_R_`y' "Excluding OFCs- Data in Million of Current USD (Receiver)"
label variable OFC_R_`y' "Data in Million of Current USD (Receiver)"
label variable world_R_`y' "Excluding OFCs-Data in Million of Current USD (Receiver)"
label variable china_R_`y' "Data in Million of Current USD (Receiver)"
label variable richest20_R_`y' "Excluding OFCs-Data in Million of Current USD (Receiver)"
}

save "$output_GDP\regions_gdp.dta", replace	

*******************************************
*Now we add data for international reserves
*******************************************
*This dataset is at the C-R level (not C-C). We know the holdings of each country in each region but not the specific countries 
*Since we don't have acq and tgt countries but only acq, we only have senders GDP

use "$input_databases\_IR.dta", clear

bysort acq year: egen total=sum(value), missing
duplicates drop acq year total, force
gen reporting=0
replace reporting=1 if total!=.
*We assign a 1 to the observations that are either 0 or positive, because we want to know which countries are reporting.
keep acq year reporting

save "$output_GDP\Reporting\reporting_sender_IR.dta", replace

use "$output_GDP\gdp.dta",clear 
keep ISO year gdp

rename ISO acq
merge 1:1 acq year using "$output_GDP\Reporting\reporting_sender_IR.dta"
keep if _merge==3
drop _merge

gen n1_acq = 0
replace n1_acq=1 if acq=="AND" |acq=="AUT" |acq=="BEL" |acq=="CAN" |acq=="DNK" |acq=="FIN" |acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="ISL" |acq=="IRL" |acq=="ITA" |acq=="JPN" |acq=="LIE" |acq=="LUX" |acq=="MCO" | ///
acq=="NLD" |acq=="NOR" |acq=="PRT" |acq=="SMR" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="GBR" |acq=="USA" 

* Additional countries in North based on BIS classification (including OFCs) 
	replace n1_acq=1 if inlist(acq,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_acq=1 if inlist(acq,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_acq=1 if inlist(acq,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_acq=1 if inlist(acq,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")

gen OFC_acq = 0
replace OFC_acq =1  if acq=="AND" | acq=="AIA" | acq=="ABW" | acq=="BHS" | acq=="BLZ" | acq=="BMU" | acq=="VGB" | acq=="CYM" | acq=="COK" | acq=="CYP" | acq=="GIB" | acq=="GGY" | acq=="IMN" | acq=="JEY" | ///
acq=="LIE" | acq=="MAC" | acq=="MCO" | acq=="MSR" | acq=="ANT" | acq=="PLW" | acq=="PAN" | acq=="WSM" | acq=="SYC" | acq=="TCA" | acq=="VUT"

// replace OFC_acq = 0	// safer, so that drops don't take effect.

replace n1_acq =0  if OFC_acq ==1

g s1_acq=0
replace s1_acq=1 if n1_acq==0  & OFC_acq==0

gen richest20_acq=0
replace richest20_acq=1 if acq =="QAT" | acq=="AUS" | acq=="SGP" | acq=="NZL" | acq=="KWT" | acq=="ARE" | acq=="BRN" | acq=="HKG" | acq=="ISR" | acq=="KOR" | /// 
						   acq =="BHR" | acq=="MLT" | acq=="SAU" | acq=="SVN" | acq=="TWN" | acq=="SVK" | acq=="BHS" | acq=="EST" | acq=="LTU" | acq=="CZE"
	
bysort year: egen north_S_IR= sum(gdp) if n1_acq==1 & reporting==1
bysort year: egen south_S_IR= sum(gdp) if s1_acq==1 & reporting==1
bysort year: egen OFC_S_IR= sum(gdp) if OFC_acq==1 & reporting==1
bysort year: egen world_S_IR= sum(gdp) if (n1_acq==1 | s1_acq==1) & reporting==1
bysort year: egen china_S_IR=sum(gdp) if acq=="CHN" & reporting==1
bysort year: egen richest20_S_IR=sum(gdp) if richest20_acq==1 & reporting==1
bysort year: egen world_OFC_S_IR = sum(gdp) if (n1_acq==1 | s1_acq==1 | OFC_acq == 1) & reporting == 1

collapse (max) north_S_IR-richest20_S_IR, by(year)

label variable north_S_IR "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable south_S_IR "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable OFC_S_IR "Data in Million of Current USD (Sender)"
label variable world_S_IR "Excluding OFCs-Data in Million of Current USD (Sender)"
label variable china_S_IR "Data in Million of Current USD (Sender)"
label variable richest20_S_IR "Excluding OFCs-Data in Million of Current USD (Sender)"

save "$output_GDP\gdp_sender_IR.dta", replace	

use "$output_GDP\regions_gdp.dta", clear	
merge 1:1 year using "$output_GDP\gdp_sender_IR.dta"
drop _merge

// save "$output_GDP\regions_gdp.dta", replace	

*Input
save "$input_databases\regions_gdp.dta", replace	

