/*
2. GDP - Region Level

********
Before running this file, make sure the databases are updated and saved in the "Input" folder
*********

In this file we aggregate the GDP by regions.

However, we will have one GDP for the region being a sender and a different one for the region being a receiver.
We will also have different GDPs depending on the database being used, even if we  are referring to the same region.

These differences come from the fact that we only want to use the GDP of the countries for which we have financial information.
We don't want to divide by the GDP of countries that we are not including when we sum the investments (we only want the reporting countries)

*/

clear all
set more off

global output_GDP "${GDP}\"

**********************************************************************************************
*First, we calculate GDP's for CPIS and FDI datasets
*GDP's for IR is calculated separately because the format of the data is different
**********************************************************************************************

*First, we obtain a list of reporting countries (senders and receivers separately) for each database

* NOTE: If hoy have access to IBS data, change the "4" to "5"
forvalues i=1/4 {

if `i' ==1 { 
use "$input_databases\_CPIS.dta",clear
local database ="CPIS"
}

if `i' ==2 { 
use "$input_databases\_CPIS_equity.dta",clear
local database ="CPIS_equity"
}

if `i' ==3 { 
use "$input_databases\_CPIS_debt.dta",clear
local database ="CPIS_debt"
}

if `i' ==4 { 
use "$input_databases\_FDI.dta",clear 
local database ="FDI"

// if `i' ==5 { 
// use "$input_databases\_IBS.dta",clear 
// local database ="IBS"

}

preserve
bysort acq year: egen total=sum(value), missing
duplicates drop acq year total, force
gen reporting=0
replace reporting=1 if total!=.
*We assign a 1 to the observations that are either 0 or positive, because we want to know which countries are reporting.
keep acq year reporting
save "$output_GDP\Reporting\reporting_sender_`database'.dta", replace

restore

bysort tgt year: egen total=sum(value), missing
duplicates drop tgt year total, force
gen reporting=0
replace reporting=1 if total!=.
keep tgt year reporting
save "$output_GDP\Reporting\reporting_receiver_`database'.dta", replace
}

*Once we have the list of reporting countries, both senders and receivers, for all the databases, we have to merge them with the GDP files. 
*We make this step to identify which countries have to be used to aggregate the GDPs (which are the reporters).

use "$output_GDP\gdp.dta",clear 

*Notice that the GDP has not been deflated.

keep ISO year gdp

// local databases "CPIS CPIS_equity CPIS_debt FDI IBS" 	// If you have access to Banking database, uncomment this
local databases "CPIS CPIS_equity CPIS_debt FDI" 

	
foreach x of local databases {
preserve
rename ISO acq
merge 1:1 acq year using "$output_GDP\Reporting\reporting_sender_`x'.dta"
keep if _merge==3
drop _merge
	
// gen n1_acq = 0
// replace n1_acq = 1 if acq=="AUS" |acq=="AUT" |acq=="BEL" |acq=="CAN"  |acq=="DNK" |acq=="FIN" | acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="HKG" |acq=="ISL" |acq=="IRL" |acq=="ISR" |acq=="ITA" |acq=="JPN" |acq=="KOR" |acq=="LUX" |acq=="NLD"|acq=="NZL" |acq=="NOR" |acq=="PRT" |acq=="SGP" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="TWN" |acq=="GBR" |acq=="USA"

gen n1_acq =0
replace n1_acq=1 if acq=="AND" |acq=="AUT" |acq=="BEL" |acq=="CAN" |acq=="DNK" |acq=="FIN" |acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="ISL" |acq=="IRL" |acq=="ITA" |acq=="JPN" |acq=="LIE" |acq=="LUX" |acq=="MCO" | ///
acq=="NLD" |acq=="NOR" |acq=="PRT" |acq=="SMR" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="GBR" |acq=="USA" 

* Additional countries in North based on BIS classification (including OFCs) 
	replace n1_acq=1 if inlist(acq,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_acq=1 if inlist(acq,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_acq=1 if inlist(acq,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_acq=1 if inlist(acq,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")


gen OFC_acq = 0
replace OFC_acq =1  if acq=="AND" | acq=="AIA" | acq=="ABW" | acq=="BHS" | acq=="BLZ" | acq=="BMU" | acq=="VGB" | acq=="CYM" | acq=="COK" | acq=="CYP" | acq=="GIB" | acq=="GGY" | acq=="IMN" | acq=="JEY" | ///
acq=="LIE" | acq=="MAC" | acq=="MCO" | acq=="MSR" | acq=="ANT" | acq=="PLW" | acq=="PAN" | acq=="WSM" | acq=="SYC" | acq=="TCA" | acq=="VUT"

replace n1_acq =0 if OFC_acq ==1

gen s1_acq=0
replace s1_acq=1 if n1_acq==0 & OFC_acq==0

*Africa + Sudan + Somalia
**************************************************
gen africa_acq=0
inlist2 acq, values(AGO, BEN, BWA, BFA, BDI, CMR, CPV, CAF, TCD, COM, COD, COG, CIV, DJI, GNQ, ERI, ETH, GAB, GMB, GHA, GIN, GNB, KEN, LSO, LBR, MDG, MWI, MLI, MRT, MUS, MOZ, NAM, NER, NGA, RWA, STP, SEN, SYC, SLE, ZAF, SSD, SUD, SWZ, TZA, TGO, UGA, ZMB, ZWE, SDN, SOM)
replace africa_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
*CaribbeanCaribbean + Barbados + Cuba + Puerto Rico + Virgin Islands (US)
**************************************************
gen caribbean_acq=0
inlist2 acq, values(ATG, BLZ, DMA, GRD, GUY, JAM, KNA, LCA, VCT, TTO, BRB, CUB, PRI, VIR)
replace caribbean_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
*LATAM+ Suriname
**************************************************
gen latam_acq=0
inlist2 acq, values(ARG, BOL, BRA, CHL, COL, CRI, DOM, ECU, SLV, GTM, HTI, HND, MEX, NIC, PAN, PRY, PER, URY, VEN, SUR)
replace latam_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2

*Commonwealth of Independent States (CIS)
**************************************************
gen cis_acq=0
inlist2 acq, values(ARM, AZE, GEO, KAZ, KGZ, RUS, TJK, TKM, UZB, MNG)
replace cis_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
*Emerging Asia + Afghanistan + America Samoa + Tuvalu
**************************************************
gen asia_acq=0
inlist2 acq, values(BGD, BTN, BRN, KHM, CHN, FJI, HKG, IND, IDN, KIR, KOR, PRK, LAO, MAC, MYS, MDV, MMR, NPL, PAK, PNG, PHL, WSM, SGP, SLB, LKA, TWN, THA, TLS, TON, VUT, VNM, AFG, ASM, TUV)
replace asia_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
*Emerging Europe + Malta + North Macedonia + Montenegro + Kosovo (exclud. Cyprus, Estonia, Lithuania, Latvia and Slovakia)
**************************************************
gen europe_acq=0
inlist2 acq, values(ALB, BLR, BIH, BGR, HRV, CZE, HUN, MDA, POL, ROU, SRB, TUR, UKR, MKD, MNE, XKX )
replace europe_acq=1 if inlist2==1
drop inlist2
* Middle East and North Africa: (MENA) + ISRAEL + Iraq + West bank and Gaza
**************************************************
gen mena_acq=0
inlist2 acq, values(BHR, IRN, JOR, KWT, LBN, OMN, QAT, SAU, SYR, ARE, EGY, YEM, DZA, LBY, MAR, TUN, ISR, IRQ, PSE)
replace mena_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
**********************
* CIS - East europe
gen CIS_EUR_acq=1 if cis_acq==1 | europe_acq==1
replace CIS_EUR_acq=0 if CIS_EUR_acq==.
* Africa - Middle East and North Africa
gen AFR_MENA_acq=1 if mena_acq==1 | africa_acq==1
replace AFR_MENA_acq=0 if AFR_MENA_acq==.
* Latin America and Caribbean Countries	
gen LAT_CAR_acq=1 if latam_acq==1 | caribbean_acq==1
replace LAT_CAR_acq=0 if LAT_CAR_acq==.

* Not classified
********************
inlist2 acq, values(ATF, CCK, CXR, ESH, FSM, GLP,GUF,GUM, MHL, MTQ,MYT,NFK,NIU,NRU,PCN,REU,SPM,TKL)
replace s1_acq = . if inlist2 == 1 
drop inlist2

gen richest20_acq=0
replace richest20_acq=1 if acq =="QAT" | acq=="AUS" | acq=="SGP" | acq=="NZL" | acq=="KWT" | acq=="ARE" | acq=="BRN" | acq=="HKG" | acq=="ISR" | acq=="KOR" | /// 
						   acq =="BHR" | acq=="MLT" | acq=="SAU" | acq=="SVN" | acq=="TWN" | acq=="SVK" | acq=="BHS" | acq=="EST" | acq=="LTU" | acq=="CZE"
/* Ranking based on IMF GDP per capita at current USD. In the 2020 update, this list was updated based using values for 2018. Barbados and Oman were replaced by Bahamas and Lithuania*/
	
bysort year: egen north_S_`x'= sum(gdp) if n1_acq==1 & reporting==1
bysort year: egen south_S_`x'= sum(gdp) if s1_acq==1 & reporting==1
bysort year: egen asia_S_`x'= sum(gdp) if asia_acq==1 & reporting==1
bysort year: egen CIS_EUR_S_`x'= sum(gdp) if CIS_EUR_acq==1 & reporting==1
bysort year: egen AFR_MENA_S_`x'= sum(gdp) if AFR_MENA_acq==1 & reporting==1
bysort year: egen LAT_CAR_S_`x'= sum(gdp) if LAT_CAR_acq==1 & reporting==1
bysort year: egen OFC_S_`x'= sum(gdp) if OFC_acq==1 & reporting==1
bysort year: egen world_S_`x'= sum(gdp) if (n1_acq==1 | asia_acq==1 |CIS_EUR_acq==1 |AFR_MENA_acq==1 |LAT_CAR_acq==1) & reporting==1
bysort year: egen china_S_`x'=sum(gdp) if acq=="CHN" & reporting==1
bysort year: egen richest20_S_`x'=sum(gdp) if richest20_acq==1 & reporting==1
bysort year: egen world_OFC_S_`x'= sum(gdp) if (n1_acq==1 | asia_acq==1 |CIS_EUR_acq==1 |AFR_MENA_acq==1 |LAT_CAR_acq==1| OFC_acq==1 ) & reporting==1
	
collapse (max) north_S_`x'-world_OFC_S_`x', by(year)

save "$output_GDP\gdp_sender_`x'.dta", replace
restore
}


foreach x of local databases {
preserve
rename ISO tgt
merge 1:1 tgt year using "$output_GDP\Reporting\reporting_receiver_`x'.dta"
keep if _merge==3
drop _merge

// gen n1_tgt = 0
// replace n1_tgt = 1 if tgt=="AUS" |tgt=="AUT" |tgt=="BEL" |tgt=="CAN"  |tgt=="DNK" |tgt=="FIN" | tgt=="FRA" |tgt=="DEU" |tgt=="GRC" |tgt=="HKG" |tgt=="ISL" |tgt=="IRL" |tgt=="ISR" |tgt=="ITA" |tgt=="JPN" |tgt=="KOR" |tgt=="LUX" |tgt=="NLD"|tgt=="NZL" |tgt=="NOR" |tgt=="PRT" |tgt=="SGP" |tgt=="ESP" |tgt=="SWE" |tgt=="CHE" |tgt=="TWN" |tgt=="GBR" |tgt=="USA"

gen n1_tgt =0
replace n1_tgt=1 if tgt=="AND" |tgt=="AUT" |tgt=="BEL" |tgt=="CAN" |tgt=="DNK" |tgt=="FIN" |tgt=="FRA" |tgt=="DEU" |tgt=="GRC" |tgt=="ISL" |tgt=="IRL" |tgt=="ITA" |tgt=="JPN" |tgt=="LIE" |tgt=="LUX" |tgt=="MCO" | ///
tgt=="NLD" |tgt=="NOR" |tgt=="PRT" |tgt=="SMR" |tgt=="ESP" |tgt=="SWE" |tgt=="CHE" |tgt=="GBR" |tgt=="USA" 

* Same for target: Additional countries in North based on BIS classification (including OFCs) 
	replace n1_tgt=1 if inlist(tgt,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_tgt=1 if inlist(tgt,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_tgt=1 if inlist(tgt,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_tgt=1 if inlist(tgt,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")

gen OFC_tgt = 0
replace OFC_tgt =1  if tgt=="AND" | tgt=="AIA" | tgt=="ABW" | tgt=="BHS" | tgt=="BLZ" | tgt=="BMU" | tgt=="VGB" | tgt=="CYM" | tgt=="COK" | tgt=="CYP" | tgt=="GIB" | tgt=="GGY" | tgt=="IMN" | tgt=="JEY" | ///
tgt=="LIE" | tgt=="MAC" | tgt=="MCO" | tgt=="MSR" | tgt=="ANT" | tgt=="PLW" | tgt=="PAN" | tgt=="WSM" | tgt=="SYC" | tgt=="TCA" | tgt=="VUT" 

replace n1_tgt =0 if OFC_tgt ==1

g s1_tgt=0
replace s1_tgt=1 if n1_tgt==0 & OFC_tgt==0	

*South countries (excluding offshore centers)
*********************************************************
*Africa + Sudan + Somalia
**************************************************
gen africa_tgt=0
inlist2 tgt, values(AGO, BEN, BWA, BFA, BDI, CMR, CPV, CAF, TCD, COM, COD, COG, CIV, DJI, GNQ, ERI, ETH, GAB, GMB, GHA, GIN, GNB, KEN, LSO, LBR, MDG, MWI, MLI, MRT, MUS, MOZ, NAM, NER, NGA, RWA, STP, SEN, SYC, SLE, ZAF, SSD, SUD, SWZ, TZA, TGO, UGA, ZMB, ZWE, SDN, SOM)
replace africa_tgt=1 if inlist2==1 & OFC_tgt ==0 & n1_tgt ==0
drop inlist2

*Caribbean + Barbados + Cuba + Puerto Rico + Virgin Islands (US)
**************************************************
gen caribbean_tgt=0
inlist2 tgt, values(ATG, BLZ, DMA, GRD, GUY, JAM, KNA, LCA, VCT, TTO, BRB, CUB, PRI, VIR)
replace caribbean_tgt=1 if inlist2==1 & OFC_tgt ==0 & n1_tgt ==0
drop inlist2
*LATAM + Suriname
**************************************************
gen latam_tgt=0
inlist2 tgt, values(ARG, BOL, BRA, CHL, COL, CRI, DOM, ECU, SLV, GTM, HTI, HND, MEX, NIC, PAN, PRY, PER, URY, VEN, SUR)
replace latam_tgt=1 if inlist2==1 & OFC_tgt ==0 & n1_tgt ==0
drop inlist2 
*Commonwealth of Independent States (CIS)
**************************************************
gen cis_tgt=0
inlist2 tgt, values(ARM, AZE, GEO, KAZ, KGZ, RUS, TJK, TKM, UZB, MNG)
replace cis_tgt=1 if inlist2==1 & OFC_tgt ==0 & n1_tgt ==0
drop inlist2
*Emerging Asia + Afghanistan + America Samoa + Tuvalu
**************************************************
gen asia_tgt=0
inlist2 tgt, values(BGD, BTN, BRN, KHM, CHN, FJI, HKG, IND, IDN, KIR, KOR, PRK, LAO, MAC, MYS, MDV, MMR, NPL, PAK, PNG, PHL, WSM, SGP, SLB, LKA, TWN, THA, TLS, TON, VUT, VNM, AFG, ASM, TUV)
replace asia_tgt=1 if inlist2==1 & OFC_tgt ==0 & n1_tgt ==0
drop inlist2
*Emerging Europe + Malta + North Macedonia + Montenegro + Kosovo (exclud. Cyprus, Estonia, Lithuania, Latvia and Slovakia)
**************************************************
gen europe_tgt=0
inlist2 tgt, values(ALB, BLR, BIH, BGR, HRV, CZE, HUN , MDA, POL, ROU, SRB, TUR, UKR, MKD, MNE, XKX)
replace europe_tgt=1 if inlist2==1
drop inlist2
* Middle East and North Africa: (MENA) + ISRAEL + Iraq + West bank and Gaza
**************************************************
gen mena_tgt=0
inlist2 tgt, values(BHR, IRN, JOR, KWT, LBN, OMN, QAT, SAU, SYR, ARE, EGY, YEM, DZA, LBY, MAR, TUN, ISR, IRQ, PSE)
replace mena_tgt=1 if inlist2==1 & OFC_tgt ==0 & n1_tgt ==0
drop inlist2
* New groups (3) and Asia
**********************
* CIS - East europe
gen CIS_EUR_tgt=1 if cis_tgt==1 | europe_tgt==1
replace CIS_EUR_tgt=0 if CIS_EUR_tgt==.
* Africa - Middle East and North Africa
gen AFR_MENA_tgt=1 if mena_tgt==1 | africa_tgt==1
replace AFR_MENA_tgt=0 if AFR_MENA_tgt==.
* Latin America and Caribbean Countries	
gen LAT_CAR_tgt=1 if latam_tgt==1 | caribbean_tgt==1
replace LAT_CAR_tgt=0 if LAT_CAR_tgt==.

inlist2 tgt, values(ATF, CCK, CXR, ESH, FSM, GLP,GUF,GUM, MHL, MTQ,MYT,NFK,NIU,NRU,PCN,REU,SPM,TKL)
replace s1_tgt = . if inlist2 == 1
drop inlist2


gen richest20_tgt=0
replace richest20_tgt=1 if tgt =="QAT" | tgt=="AUS" | tgt=="SGP" | tgt=="NZL" | tgt=="KWT" | tgt=="ARE" | tgt=="BRN" | tgt=="HKG" | tgt=="ISR" | tgt=="KOR" | /// 
						   tgt =="BHR" | tgt=="MLT" | tgt=="SAU" | tgt=="SVN" | tgt=="TWN" | tgt=="SVK" | tgt=="BHS" | tgt=="EST" | tgt=="LTU" | tgt=="CZE"
	
bysort year: egen north_R_`x'= sum(gdp) if n1_tgt==1 & reporting==1
bysort year: egen south_R_`x'= sum(gdp) if s1_tgt==1 & reporting==1
bysort year: egen asia_R_`x'= sum(gdp) if asia_tgt==1 & reporting==1
bysort year: egen CIS_EUR_R_`x'= sum(gdp) if CIS_EUR_tgt==1 & reporting==1
bysort year: egen AFR_MENA_R_`x'= sum(gdp) if AFR_MENA_tgt==1 & reporting==1
bysort year: egen LAT_CAR_R_`x'= sum(gdp) if LAT_CAR_tgt==1 & reporting==1
bysort year: egen OFC_R_`x'= sum(gdp) if OFC_tgt==1 & reporting==1
bysort year: egen world_R_`x'= sum(gdp) if (n1_tgt==1 | asia_tgt==1 |CIS_EUR_tgt==1 |AFR_MENA_tgt==1 | LAT_CAR_tgt==1) & reporting==1
bysort year: egen china_R_`x'=sum(gdp) if tgt=="CHN" & reporting==1
bysort year: egen richest20_R_`x'=sum(gdp) if richest20_tgt==1 & reporting==1
bysort year: egen world_OFC_R_`x'= sum(gdp) if (n1_tgt==1 | asia_tgt==1 |CIS_EUR_tgt==1 |AFR_MENA_tgt==1 |LAT_CAR_tgt==1| OFC_tgt==1 ) & reporting==1
		
collapse (max) north_R_`x'-world_OFC_R_`x', by(year)

save "$output_GDP\gdp_receiver_`x'.dta", replace
restore
}
	
use "$output_GDP\gdp_sender_CPIS.dta", clear
// local databases_2 "CPIS_equity CPIS_debt FDI IBS" // If you have access to Banking database, uncomment this
local databases_2 "CPIS_equity CPIS_debt FDI"
foreach z of local databases_2 {
merge 1:1 year using "$output_GDP\gdp_sender_`z'.dta"
drop _merge
}

// local databases_3 "CPIS CPIS_equity CPIS_debt FDI IBS" // If you have access to Banking database, uncomment this
local databases_3 "CPIS CPIS_equity CPIS_debt FDI"
foreach y of local databases_3 {
merge 1:1 year using "$output_GDP\gdp_receiver_`y'.dta"
drop _merge
}

*Now we have a Regions_GDP file where each column reports the value of the corresponding region GDP for a given database. 

foreach y of local databases_3 {
label variable asia_S_`y' "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable CIS_EUR_S_`y'  "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable AFR_MENA_S_`y'  "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable LAT_CAR_S_`y'  "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable north_S_`y' "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable south_S_`y' "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable OFC_S_`y' "Data in Million of Current USD (Sender)"
label variable world_S_`y' "Excluding OFCs-Data in Million of Current USD (Sender)"
label variable china_S_`y' "Data in Million of Current USD (Sender)"
label variable richest20_S_`y' "Excluding OFCs-Data in Million of Current USD (Sender)"

label variable asia_R_`y' "Excluding OFCs- Data in Million of Current USD (Receiver)"
label variable CIS_EUR_R_`y'"Excluding OFCs- Data in Million of Current USD (Receiver)"
label variable AFR_MENA_R_`y'  "Excluding OFCs- Data in Million of Current USD (Receiver)"
label variable LAT_CAR_R_`y'  "Excluding OFCs- Data in Million of Current USD (Receiver)"
label variable north_R_`y' "Excluding OFCs- Data in Million of Current USD (Receiver)"
label variable south_R_`y' "Excluding OFCs- Data in Million of Current USD (Receiver)"
label variable OFC_R_`y' "Data in Million of Current USD (Receiver)"
label variable world_R_`y' "Excluding OFCs-Data in Million of Current USD (Receiver)"
label variable china_R_`y' "Data in Million of Current USD (Receiver)"
label variable richest20_R_`y' "Excluding OFCs-Data in Million of Current USD (Receiver)"
}

save "$output_GDP\regions_gdp_regions.dta", replace	

*******************************************
*Now we add data for international reserves
*******************************************
*This dataset is at the C-R level (not C-C). We know the holdings of each country in each region but not the specific countries 
*Since we don't have acq and tgt countries but only acq, we only have senders GDP

use "$input_databases\_IR.dta", clear

bysort acq year: egen total=sum(value), missing
duplicates drop acq year total, force
gen reporting=0
replace reporting=1 if total!=.
*We assign a 1 to the observations that are either 0 or positive, because we want to know which countries are reporting.
keep acq year reporting

save "$output_GDP\Reporting\reporting_sender_IR.dta", replace

use "$output_GDP\gdp.dta",clear 
keep ISO year gdp

rename ISO acq
merge 1:1 acq year using "$output_GDP\Reporting\reporting_sender_IR.dta"
keep if _merge==3
drop _merge

	
// gen n1_acq = 0
// replace n1_acq = 1 if acq=="AUS" |acq=="AUT" |acq=="BEL" |acq=="CAN"  |acq=="DNK" |acq=="FIN" | acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="HKG" |acq=="ISL" |acq=="IRL" |acq=="ISR" |acq=="ITA" |acq=="JPN" |acq=="KOR" |acq=="LUX" |acq=="NLD"|acq=="NZL" |acq=="NOR" |acq=="PRT" |acq=="SGP" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="TWN" |acq=="GBR" |acq=="USA"

gen n1_acq =0
replace n1_acq=1 if acq=="AND" |acq=="AUT" |acq=="BEL" |acq=="CAN" |acq=="DNK" |acq=="FIN" |acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="ISL" |acq=="IRL" |acq=="ITA" |acq=="JPN" |acq=="LIE" |acq=="LUX" |acq=="MCO" | ///
acq=="NLD" |acq=="NOR" |acq=="PRT" |acq=="SMR" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="GBR" |acq=="USA" 

* Additional countries in North based on BIS classification (including OFCs) 
	replace n1_acq=1 if inlist(acq,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_acq=1 if inlist(acq,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_acq=1 if inlist(acq,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_acq=1 if inlist(acq,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")


gen OFC_acq = 0
replace OFC_acq =1  if acq=="AND" | acq=="AIA" | acq=="ABW" | acq=="BHS" | acq=="BLZ" | acq=="BMU" | acq=="VGB" | acq=="CYM" | acq=="COK" | acq=="CYP" | acq=="GIB" | acq=="GGY" | acq=="IMN" | acq=="JEY" | ///
acq=="LIE" | acq=="MAC" | acq=="MCO" | acq=="MSR" | acq=="ANT" | acq=="PLW" | acq=="PAN" | acq=="WSM" | acq=="SYC" | acq=="TCA" | acq=="VUT"

replace n1_acq =0 if OFC_acq ==1

gen s1_acq=0
replace s1_acq=1 if n1_acq==0 & OFC_acq==0

*Africa + Sudan + Somalia
**************************************************
gen africa_acq=0
inlist2 acq, values(AGO, BEN, BWA, BFA, BDI, CMR, CPV, CAF, TCD, COM, COD, COG, CIV, DJI, GNQ, ERI, ETH, GAB, GMB, GHA, GIN, GNB, KEN, LSO, LBR, MDG, MWI, MLI, MRT, MUS, MOZ, NAM, NER, NGA, RWA, STP, SEN, SYC, SLE, ZAF, SSD, SUD, SWZ, TZA, TGO, UGA, ZMB, ZWE, SDN, SOM)
replace africa_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
*CaribbeanCaribbean + Barbados + Cuba + Puerto Rico + Virgin Islands (US)
**************************************************
gen caribbean_acq=0
inlist2 acq, values(ATG, BLZ, DMA, GRD, GUY, JAM, KNA, LCA, VCT, TTO, BRB, CUB, PRI, VIR)
replace caribbean_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
*LATAM+ Suriname
**************************************************
gen latam_acq=0
inlist2 acq, values(ARG, BOL, BRA, CHL, COL, CRI, DOM, ECU, SLV, GTM, HTI, HND, MEX, NIC, PAN, PRY, PER, URY, VEN, SUR)
replace latam_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2

*Commonwealth of Independent States (CIS)
**************************************************
gen cis_acq=0
inlist2 acq, values(ARM, AZE, GEO, KAZ, KGZ, RUS, TJK, TKM, UZB, MNG)
replace cis_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
*Emerging Asia + Afghanistan + America Samoa + Tuvalu
**************************************************
gen asia_acq=0
inlist2 acq, values(BGD, BTN, BRN, KHM, CHN, FJI, HKG, IND, IDN, KIR, KOR, PRK, LAO, MAC, MYS, MDV, MMR, NPL, PAK, PNG, PHL, WSM, SGP, SLB, LKA, TWN, THA, TLS, TON, VUT, VNM, AFG, ASM, TUV)
replace asia_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
*Emerging Europe + Malta + North Macedonia + Montenegro + Kosovo (exclud. Cyprus, Estonia, Lithuania, Latvia and Slovakia)
**************************************************
gen europe_acq=0
inlist2 acq, values(ALB, BLR, BIH, BGR, HRV, CZE, HUN, MDA, POL, ROU, SRB, TUR, UKR, MKD, MNE, XKX )
replace europe_acq=1 if inlist2==1
drop inlist2
* Middle East and North Africa: (MENA) + ISRAEL + Iraq + West bank and Gaza
**************************************************
gen mena_acq=0
inlist2 acq, values(BHR, IRN, JOR, KWT, LBN, OMN, QAT, SAU, SYR, ARE, EGY, YEM, DZA, LBY, MAR, TUN, ISR, IRQ, PSE)
replace mena_acq=1 if inlist2==1 & OFC_acq ==0 & n1_acq ==0
drop inlist2
**********************
* CIS - East europe
gen CIS_EUR_acq=1 if cis_acq==1 | europe_acq==1
replace CIS_EUR_acq=0 if CIS_EUR_acq==.
* Africa - Middle East and North Africa
gen AFR_MENA_acq=1 if mena_acq==1 | africa_acq==1
replace AFR_MENA_acq=0 if AFR_MENA_acq==.
* Latin America and Caribbean Countries	
gen LAT_CAR_acq=1 if latam_acq==1 | caribbean_acq==1
replace LAT_CAR_acq=0 if LAT_CAR_acq==.

* Not classified
********************
inlist2 acq, values(ATF, CCK, CXR, ESH, FSM, GLP,GUF,GUM, MHL, MTQ,MYT,NFK,NIU,NRU,PCN,REU,SPM,TKL)
replace s1_acq = . if inlist2 == 1 
drop inlist2

gen richest20_acq=0
replace richest20_acq=1 if acq =="QAT" | acq=="AUS" | acq=="SGP" | acq=="NZL" | acq=="KWT" | acq=="ARE" | acq=="BRN" | acq=="HKG" | acq=="ISR" | acq=="KOR" | /// 
						   acq =="BHR" | acq=="MLT" | acq=="SAU" | acq=="SVN" | acq=="TWN" | acq=="SVK" | acq=="BHS" | acq=="EST" | acq=="LTU" | acq=="CZE"
	
bysort year: egen north_S_IR= sum(gdp) if n1_acq==1 & reporting==1
bysort year: egen south_S_IR= sum(gdp) if s1_acq==1 & reporting==1
bysort year: egen asia_S_IR= sum(gdp) if asia_acq==1 & reporting==1
bysort year: egen CIS_EUR_S_IR= sum(gdp) if CIS_EUR_acq==1 & reporting==1
bysort year: egen AFR_MENA_S_IR= sum(gdp) if AFR_MENA_acq==1 & reporting==1
bysort year: egen LAT_CAR_S_IR= sum(gdp) if LAT_CAR_acq==1 & reporting==1
bysort year: egen OFC_S_IR= sum(gdp) if OFC_acq==1 & reporting==1
bysort year: egen world_S_IR= sum(gdp) if (n1_acq==1 | asia_S_IR==1 |CIS_EUR_S_IR==1 |AFR_MENA_S_IR==1 |LAT_CAR_S_IR==1) & reporting==1
bysort year: egen china_S_IR=sum(gdp) if acq=="CHN" & reporting==1
bysort year: egen richest20_S_IR=sum(gdp) if richest20_acq==1 & reporting==1

collapse (max) north_S_IR-richest20_S_IR, by(year)

label variable north_S_IR "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable south_S_IR "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable asia_S_IR "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable CIS_EUR_S_IR  "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable AFR_MENA_S_IR  "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable LAT_CAR_S_IR  "Excluding OFCs- Data in Million of Current USD (Sender)"
label variable OFC_S_IR "Data in Million of Current USD (Sender)"
label variable world_S_IR "Excluding OFCs-Data in Million of Current USD (Sender)"
label variable china_S_IR "Data in Million of Current USD (Sender)"
label variable richest20_S_IR "Excluding OFCs-Data in Million of Current USD (Sender)"

save "$output_GDP\gdp_sender_IR.dta", replace	

use "$output_GDP\regions_gdp_regions.dta", clear	
merge 1:1 year using "$output_GDP\gdp_sender_IR.dta"
drop _merge

save "$output_GDP\regions_gdp_regions.dta", replace	

*Input
save "$input_databases\regions_gdp_regions.dta", replace	

