/****************************************************************************************************
This do file generates the input for F1 - Comparison with Lane and Milesi-Ferretti

This figure shows for each type of investment the yearly aggregated value in our data and LMF's data

To make the comparison, we only leave countries and years that appear in both datasets
We do include OFCs that are in both datasets in the comparison

This do file performs 3 different tasks:
1. Merge our data into a single database
2. Create our and LMF dataset leaving only countries in both samples
3. Calculate aggregate yearly values for the figures

*****************************************************************************************************/

clear all
set more off

******************************************
* 1. Merge our data into a single database
******************************************
*For each dataset, create a new set that has for each country and year, the total value of cross-border assets 

// local databases "IBS CPIS FDI IR" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI IR"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
bysort acq year: egen `x'_value=sum(value), missing
duplicates drop acq year, force
keep acq year `x'_value
save "$Output\aux_`x'.dta", replace
}

*Merge all datasets into a single file
use "$Output\aux_CPIS.dta", clear

// local databases "IBS FDI IR" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "FDI IR"
foreach x of local databases {
merge 1:1 acq year using "$Output\aux_`x'.dta"
drop _merge
}

*Give variables same name as in LMF data
rename CPIS_value port_value

*Classify countries into regions
*We cannot use the dofile "North-South classification" becasue it is coded for when you have acq and tgt (now we only have acq)
*North Countries (High income definition including offshore centers) 
**************************************************
gen n1_acq =0
replace n1_acq=1 if acq=="AND" |acq=="AUT" |acq=="BEL" |acq=="CAN" |acq=="DNK" |acq=="FIN" |acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="ISL" |acq=="IRL" |acq=="ITA" |acq=="JPN" |acq=="LIE" |acq=="LUX" |acq=="MCO" | ///
acq=="NLD" |acq=="NOR" |acq=="PRT" |acq=="SMR" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="GBR" |acq=="USA" 

* Additional countries in North based on BIS classification (including OFCs) 
	replace n1_acq=1 if inlist(acq,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_acq=1 if inlist(acq,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_acq=1 if inlist(acq,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_acq=1 if inlist(acq,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")

*Offshore Centers (25)			<--- UNCHANGED
**********************
g OFC_acq = 0
replace OFC_acq =1  if acq=="AND" | acq=="AIA" | acq=="ABW" | acq=="BHS" | acq=="BLZ" | acq=="BMU" | acq=="VGB" | acq=="CYM" | acq=="COK" | acq=="CYP" | acq=="GIB" | acq=="GGY" | acq=="IMN" | acq=="JEY" | ///
acq=="LIE" | acq=="MAC" | acq=="MCO" | acq=="MSR" | acq=="ANT" | acq=="PLW" | acq=="PAN" | acq=="WSM" | acq=="SYC" | acq=="TCA" | acq=="VUT" 

*Excluding Offshore centers from North Countries
**********************************************
replace n1_acq =0 if OFC_acq ==1

*South countries (excluding offshore centers)
*********************************************************
g s1_acq=0
replace s1_acq=1 if n1_acq==0 & OFC_acq ==0

save "$Output\Our_full.dta", replace

erase "$Output\aux_CPIS.dta"
erase "$Output\aux_FDI.dta"
erase "$Output\aux_IR.dta"
// erase "$Output\aux_IBS.dta" // If you have access to Banking data, uncomment this.

*Finally, we make a list of all countries in our data
preserve
keep acq year
save "$Output\listcountries_our.dta", replace
restore

***********************************************
* 2. Create datasets with same set of countries
***********************************************
*Build list of all countries in LMF data
use "$Input\_LMF.dta", clear
keep acq year
save "$Output\listcountries_LMF.dta", replace

*Build list of countries in both samples
merge 1:1 acq year using "$Output\listcountries_our.dta"
keep if _merge==3
drop _merge

save "$Output\listcountries_both.dta", replace

*In our data, keep only countries in both samples
use "$Output\Our_full.dta", clear
merge 1:1 acq year using "$Output\listcountries_both.dta"
keep if _merge==3
drop _merge
save "$Output\_Our_rest.dta", replace

*In LMF data, keep only countries in both samples
use "$Input\_LMF.dta", clear
merge 1:1 acq year using "$Output\listcountries_both.dta"
keep if _merge==3 //merge=2 for years 2016-18, for which LMF has no data
drop _merge
save "$Output\_LMF_rest.dta", replace

********************************
* 3. Calculate input for figures
********************************

*Our data
*********
use "$Output\_Our_rest.dta" ,clear 

*Flows per type
bysort year: egen port_World=sum(port_value) 
bysort year: egen FDI_World=sum(FDI_value)
bysort year: egen IR_World=sum(IR_value)
// bysort year: egen IBS_World=sum(IBS_value) // If you have access to Banking database, uncomment this.

*Data in trillion USD
*Note we keep data in current values
replace port_World=port_World/1000000
replace FDI_World=FDI_World/1000000
replace IR_World=IR_World/1000000
// replace IBS_World=IBS_World/1000000 // If you have access to Banking database, uncomment this.

collapse (min) port_World FDI_World IR_World, by(year)
// collapse (min) IBS_World port_World FDI_World IR_World, by(year) // If you have access to Banking database, uncomment this.

export excel using "$Output\F1.xlsx", sheet(Our_rest) sheetreplace firstrow(variables)

*LMF data
*********
use "$Output\_LMF_rest.dta" ,clear 

*Flows per type
//We exclude OFCs
bysort year: egen bank_World=sum(bank_value)
bysort year: egen port_World=sum(port_value)
bysort year: egen FDI_World=sum(FDI_value)
bysort year: egen IR_World=sum(IR_value)

*Data in trillion USD
*Note we keep data in current values
replace bank_World=bank_World/1000000
replace port_World=port_World/1000000
replace FDI_World=FDI_World/1000000
replace IR_World=IR_World/1000000

collapse (min) bank_World port_World FDI_World IR_World, by(year)

export excel using "$Output\F1.xlsx", sheet(LMF_rest) sheetreplace firstrow(variables)

erase "$Output\listcountries_LMF.dta"
erase "$Output\listcountries_our.dta"
erase "$Output\listcountries_both.dta"
erase "$Output\Our_full.dta"
erase "$Output\_Our_rest.dta"
erase "$Output\_LMF_rest.dta"

