/**********************************************************************************************************************************************************************************************
This do file generates the input for Figure 2 - Evolution of Regional Level Investments and Connections

For each investment type and year, it calculates the value of old and new connections, and percentage of active connections

- The % of active connections is computed as the number of country-pairs that have a positive or negative value in each year over the number of country-pairs with a positive, negative or zero value in that same year. Note that many values are missing (they are not zeros) and we are not counting these observations in the denominator.
   
- New investments are defined as those investments attributable to connections that were not present in the 1st year of each database (2001)

- Old investments are defined as those investments attributable to connections that were already present in the 1st year of each database (2001)
   
We define the "1st period" as the first year in our sample (2001)
   
Flows are expressed in trillions of 2011 USD.	
**********************************************************************************************************************************************************************************************/
clear all
set more off

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"
foreach x of local databases {
use "$Input\_`x'.dta" ,clear

*We need to define a "1st period" to distinguish old and new connections
*In our case, we define the period to be the first year in each dataset (2001)
egen first_year_start= min(year)  //Initial date of the 1st period
egen first_year_end=min(year)  //Final date of the 1st period

*Deflating prices (2011 billions USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
drop if _merge != 3
replace value = (value / deflator) //check this
label variable value "2011 Trillions, USD"
drop _merge deflator

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"


*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*Identifying NEW and OLD connections (with respect to the 1st year)
gen year1=0
replace year1=1 if value!=0 & value!=. & year>=first_year_start & year<=first_year_end
bysort country_dyad: egen sample=max(year1)
drop year1
//If sample ==1, the connection is OLD (with respect to the 1st year). -In the 1st year it was a positive link between the source and target country-.
//If sample ==0, the bilateral link is NEW (with respect to the 1st year).

*Summing value of OLD and NEW connections
*****************************************
//OLD CONECTIONS (sample ==1)
bysort year: egen nn_old=sum(value) if n1_acq==1 & n1_tgt==1 & sample==1
bysort year: egen ns_old=sum(value) if n1_acq==1 & s1_tgt==1 & sample==1
bysort year: egen sn_old=sum(value) if s1_acq==1 & n1_tgt==1 & sample==1
bysort year: egen ss_old=sum(value) if s1_acq==1 & s1_tgt==1 & sample==1
//NEW CONECTIONS (sample ==0)
bysort year: egen nn_new=sum(value) if n1_acq==1 & n1_tgt==1 & sample==0
bysort year: egen ns_new=sum(value) if n1_acq==1 & s1_tgt==1 & sample==0
bysort year: egen sn_new=sum(value) if s1_acq==1 & n1_tgt==1 & sample==0
bysort year: egen ss_new=sum(value) if s1_acq==1 & s1_tgt==1 & sample==0

// * % of Active Connections
// *************************
// *Note:The % of active connections is computed as the number of country-pairs that have a positive or negative value in each year over the number of country-pairs with a positive, negative or zero value in that same year (we do not include missings)
//
// *Active Links
// bysort year: egen count_NN_active=count(value) if value!=0 & value!=. & n1_acq==1 & n1_tgt==1 
// bysort year: egen count_NS_active=count(value) if value!=0 & value!=. & n1_acq==1 & s1_tgt==1
// bysort year: egen count_SN_active=count(value) if value!=0 & value!=. & s1_acq==1 & n1_tgt==1
// bysort year: egen count_SS_active=count(value) if value!=0 & value!=. & s1_acq==1 & s1_tgt==1
// *Active and Non-active Links
// bysort year: egen count_NN_all=count(value) if value!=. & n1_acq==1 & n1_tgt==1
// bysort year: egen count_NS_all=count(value) if value!=. & n1_acq==1 & s1_tgt==1
// bysort year: egen count_SN_all=count(value) if value!=. & s1_acq==1 & n1_tgt==1
// bysort year: egen count_SS_all=count(value) if value!=. & s1_acq==1 & s1_tgt==1
// *Percentage of Active Connections
// gen nn_active=count_NN_active / count_NN_all
// gen ns_active=count_NS_active / count_NS_all
// gen sn_active=count_SN_active / count_SN_all
// gen ss_active=count_SS_active / count_SS_all
//
// collapse (min) nn_new nn_old nn_active	  ns_new ns_old ns_active	  sn_new sn_old sn_active	  ss_new ss_old ss_active, by(year)

* Total connections
collapse (min) nn_* ns_* sn_* ss_*, by(year)

* Merge with World GDP
merge 1:1 year using "$Input\regions_gdp.dta", keepus(world_R_`x')

foreach y in nn ns sn ss{
bys year: gen `y'_total = (`y'_old + `y'_new)/world_R_`x'
}

drop _merge world_R_`x'
order year nn_new nn_old nn_total	ns_new ns_old ns_total	sn_new sn_old sn_total	ss_new ss_old ss_total 

export excel using "$Output\F2.xlsx", sheet(`x') sheetreplace firstrow(variables)
}


**************
*Int. Reserves
**************
use "$Input\_IR.dta", clear 

egen first_year_start= min(year)  //Initial date of the 1st period
egen first_year_end=min(year)  //Final date of the 1st period

*Deflating prices (2011 billions USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
drop if _merge != 3
replace value = (value / deflator)
label variable value "2011 Trillions, USD"
drop _merge deflator


*IR dataset already identifies region of acq country
*We exclude Offshore Centers as senders (we don't have receiver countries for IR)
drop if OFC_acq ==1
drop OFC_acq

*Identifying NEW and OLD connections (with respect to the 1st year)

gen country_dyad = acq+"_"+tgt
gen year1=0
replace year1=1 if value!=0 & value!=. & year>=first_year_start & year<=first_year_end
bysort country_dyad: egen sample=max(year1)
drop year1
//If sample ==1, the connection is OLD (with respect to the 1st year). -In the 1st year it was a positive link between the source and target country-.
//If sample ==0, the bilateral link is NEW (with respect to the 1st year).

*Summing value of OLD and NEW connections
*****************************************
//OLD CONECTIONS (sample ==1)
bysort year: egen nn_old=sum(value) if n1_acq==1 & n1_tgt==1 & sample==1
bysort year: egen ns_old=sum(value) if n1_acq==1 & s1_tgt==1 & sample==1
bysort year: egen sn_old=sum(value) if s1_acq==1 & n1_tgt==1 & sample==1
bysort year: egen ss_old=sum(value) if s1_acq==1 & s1_tgt==1 & sample==1
//NEW CONECTIONS (sample ==0)
bysort year: egen nn_new=sum(value) if n1_acq==1 & n1_tgt==1 & sample==0
bysort year: egen ns_new=sum(value) if n1_acq==1 & s1_tgt==1 & sample==0
bysort year: egen sn_new=sum(value) if s1_acq==1 & n1_tgt==1 & sample==0
bysort year: egen ss_new=sum(value) if s1_acq==1 & s1_tgt==1 & sample==0

// * % of Active Connections
// *************************
// *Note:The % of active connections is computed as the number of country-pairs that have a positive or negative value in each year over the number of country-pairs with a positive, negative or zero value in that same year (we do not include missings)
//
// *Active Links
// bysort year: egen count_NN_active=count(value) if value!=0 & value!=. & n1_acq==1 & n1_tgt==1 
// bysort year: egen count_NS_active=count(value) if value!=0 & value!=. & n1_acq==1 & s1_tgt==1
// bysort year: egen count_SN_active=count(value) if value!=0 & value!=. & s1_acq==1 & n1_tgt==1
// bysort year: egen count_SS_active=count(value) if value!=0 & value!=. & s1_acq==1 & s1_tgt==1
// *Active and Non-active Links
// bysort year: egen count_NN_all=count(value) if value!=. & n1_acq==1 & n1_tgt==1
// bysort year: egen count_NS_all=count(value) if value!=. & n1_acq==1 & s1_tgt==1
// bysort year: egen count_SN_all=count(value) if value!=. & s1_acq==1 & n1_tgt==1
// bysort year: egen count_SS_all=count(value) if value!=. & s1_acq==1 & s1_tgt==1
// *Percentage of Active Connections
// gen nn_active=count_NN_active / count_NN_all
// gen ns_active=count_NS_active / count_NS_all
// gen sn_active=count_SN_active / count_SN_all
// gen ss_active=count_SS_active / count_SS_all
//
// collapse (min) nn_new nn_old nn_active	  ns_new ns_old ns_active	  sn_new sn_old sn_active	  ss_new ss_old ss_active, by(year)

* Total connections
collapse (min) nn_* ns_* sn_* ss_*, by(year)

* Merge with World GDP
merge 1:1 year using "$Input\regions_gdp.dta", keepus(world_S_IR)

foreach x in nn ns sn ss{
bys year: gen `x'_total = (`x'_old + `x'_new)/world_S_IR
}

drop _merge world_S_IR
order year nn_new nn_old nn_total	ns_new ns_old ns_total	sn_new sn_old sn_total	ss_new ss_old ss_total 

export excel using "$Output\F2.xlsx", sheet(IR) sheetreplace firstrow(variables)