/**********************************************************************************************************************************************************************************************
This do file generates the input for Figure 6 - Growth in the Value of International Investment Positions

For each investment type and block, it calculates the growth taking 2001 as the base year. Also, it calculates only for the 5th quintile of average GDP by sender and receiver.

- The figure is made only for C-C aggregation, including country-pair FE.
- Quintile database are calculated in the dofile
- We export OLS and PPML


**********************************************************************************************************************************************************************************************/
clear all
set more off
set matsize 11000
set maxvar 32767

***************
* IBS, CPIS and FDI
***************

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
replace value=. if value<0 //PPML does not work with negative values
sum year
scalar first_year= r(min)
scalar last_year= r(max)
scalar total_years= (last_year-first_year) + 1
keep if year>=`=scalar(first_year)' & year<=`=scalar(last_year)'

*Deflating prices (2011 millions USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
drop if _merge != 3
replace value = value / deflator
label variable value "2011 Millions, USD"
drop _merge deflator

*Separating North and South countries (both exclude offshore centers)
// do "$Dofiles\North-South classification.do"
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*Creating region-pairs dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if n1_acq==1 & n1_tgt==1
replace ns=1 if n1_acq==1 & s1_tgt==1
replace sn=1 if s1_acq==1 & n1_tgt==1
replace ss=1 if s1_acq==1 & s1_tgt==1


*Deflating Values (2011 USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
keep if _merge==3
replace gdp_acq = gdp_acq / deflator
replace gdp_tgt = gdp_tgt / deflator
label variable gdp_acq "Millions of 2011 USD"
label variable gdp_tgt "Millions of 2011 USD"
drop _merge deflator
		
*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' 
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

*Creating Country-Country dummies
drop country_dyad
gen country_dyad = acq+"_"+tgt
egen group = group(country_dyad)
xtset group year

*Creating the dependent variable and log gdp.
gen l_value = log(value)
gen n_value = value /sqrt(gdp_acq * gdp_tgt)
gen nn_value = log(n_value)


* Percentile GDP: average for all years, first year and last year
* Note: This Percentile is calculated excluding the OFCs.
preserve
collapse (mean) gdp_acq1 = gdp_acq , by(acq)
xtile pct_gdp_s = gdp_acq1, n(5)
gen pct_gdp_s1 = pct_gdp_s // to merge with tgt
gen tgt = acq
save "$Output\aux_GDP_rank_s.dta", replace
restore

*Regressions
**************
* Merging with senders and receivers (to be sure that we have 5th quintile in both directions)
merge m:1 acq using "$Output\aux_GDP_rank_s.dta", nogen  keepus(pct_gdp_s)
merge m:1 tgt using "$Output\aux_GDP_rank_s.dta", nogen  keepus(pct_gdp_s1)

* Defining the quintile
local k = 5

* OLS Trends
reghdfe nn_value 1.nn#i(1/17)bn.trend 1.ns#i(1/17)bn.trend 1.sn#i(1/17)bn.trend 1.ss#i(1/17)bn.trend if pct_gdp_s>=`k' & pct_gdp_s1>=`k',  absorb(country_dyad) cluster(country_dyad) baselevels
outreg2 nn_value  using "$Output\F6.xls", ctitle("OLS `x' newdep") ///
                 bdec(3) cons nose noaster excel  

* PPML Trends
ppmlhdfe n_value 1.nn#i(1/17)bn.trend 1.ns#i(1/17)bn.trend 1.sn#i(1/17)bn.trend 1.ss#i(1/17)bn.trend if pct_gdp_s>=`k' & pct_gdp_s1>=`k', absorb(country_dyad) cluster(country_dyad)		
outreg2 n_value  using "$Output\F6.xls", ctitle("PPML `x' newdep") ///
                 bdec(3) cons nose noaster excel  		
}

erase "$Output\aux_GDP_rank_s.dta"

