/* *********************************************************************************************************************************************************************************************************************
This do file runs all the regressions for Online Appendix Table 3 - FDI: Intensive Margin Regressions Robustness.

We run T3 for FDI but, in this case, we account for the observed jump in the series in 2009, when we start to use IMF data (in F2 we can see how the share of active connections jump in 2009)

To adjust for this jump, we add region-region dummies interacted with a dummy that is 1 from 2009 onwards

- In previous versions, we also tried other robustness (use a balanced sample and adding country-region dummies that can change from 2009 onwards). This is in older do files

************************************************************************************************************************************************************************************************************************* */

clear all
set more off
set matsize 11000
set maxvar 32767

local databases "FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
replace value=. if value<0 //PPML does not work with negative values
sum year
scalar first_year= r(min)
scalar last_year= r(max)
scalar total_years= (last_year-first_year) + 1
keep if year>=`=scalar(first_year)' & year<=`=scalar(last_year)'

*Deflating prices (2011 millions USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
drop if _merge != 3
replace value = value / deflator
label variable value "2011 Millions, USD"
drop _merge deflator

*Separating North and South countries (both exclude offshore centers)
// do "$Dofiles\North-South classification.do"
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*Creating region-pairs dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if n1_acq==1 & n1_tgt==1
replace ns=1 if n1_acq==1 & s1_tgt==1
replace sn=1 if s1_acq==1 & n1_tgt==1
replace ss=1 if s1_acq==1 & s1_tgt==1

**************************
*REGION-REGION REGRESSIONS
**************************
preserve
egen sum=sum(value), missing by(year nn ns sn ss)
collapse (max) sum, by(year nn ns sn ss)
rename sum value
gen l_value  = log(value) 
save "$Output\auxx.dta" , replace

*Merging with GDPs
	*Working first with the GDP database, to match the format
    use "$Input\regions_gdp.dta", clear
	keep year north_S_`x' north_R_`x' south_S_`x' south_R_`x'
	
	expand 4, gen(duplicate)
	*duplicate==1 if the observation is duplicated and 0 if it was originally in the dataset.
	egen group= group(year)
	sort group
	by group: gen count= _n
	sort count year
	gen nn=0
	g ns=0
	g sn=0
	g ss=0
	replace nn=1 if count==1
	replace ns=1 if count==2
	replace sn=1 if count==3
	replace ss=1 if count==4
	
	gen Gdp_Avg =0
	replace Gdp_Avg=  sqrt(north_S_`x'*north_R_`x') if nn==1
	replace Gdp_Avg=  sqrt(north_S_`x'*south_R_`x') if ns==1
	replace Gdp_Avg=  sqrt(south_S_`x'*north_R_`x') if sn==1
	replace Gdp_Avg=  sqrt(south_S_`x'*south_R_`x') if ss==1
	keep year nn ns sn ss Gdp_Avg

	*Deflating GDPs (given that I deflated flows before)
    merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
	keep if _merge ==3
	replace Gdp_Avg = Gdp_Avg / deflator
	label variable Gdp_Avg "Millions of 2011 USD"
	drop _merge deflator
	save "$Output\gdp_region_aux.dta", replace

use "$Output\auxx.dta", clear
merge 1:1 year nn ns sn ss using "$Output\gdp_region_aux.dta"
keep if _merge ==3 //The merge is by region, not country. Therefore _merge always equals 3, except if the year is not included in the main database. We are not dropping obs here.
drop _merge

*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' //Note that the 1st year has trend==0.
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

///////////////////Adjusting for the jump ///////////////////
*Create interaction Region-Region dummies and post-2009 dummy
gen nn_post=0
gen ns_post=0
gen sn_post=0
gen ss_post=0
replace nn_post=1 if nn==1 & year>=2009
replace ns_post=1 if ns==1 & year>=2009
replace sn_post=1 if sn==1 & year>=2009
replace ss_post=1 if ss==1 & year>=2009	
///////////////////////////////////////////////////////////////

*Regressions
*************
*1) Dependent Variable: Log(Value). Estimation method: OLS
reg l_value  nn ns sn ss  nn_post ns_post sn_post ss_post  nn_trend ns_trend sn_trend ss_trend, robust
*When using the "nocons" option the estimates for the coefficients are exactly the same but the R-squared (and Adjusted R-squared) changes.
*This is because Stata is assuming that we are forcing our constant to be zero.
*Therefore, it is better to include all the constants and allow Stata to drop one of them because of multicollinearity. Another option is to use "hasconstant" to make Stata know that one of the dummies is the constant.
*Unless we want to report the coefficients for the dummies (and not just the interactions with the trend).

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
			outreg2 l_value using "$Output\OAT3.xls", ctitle("OLS R-R log(value)") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R") ///
				 keep(nn_trend ns_trend sn_trend ss_trend) bdec(3) excel replace

restore

**************************************
*COUNTRY-REGION and REGION-COUNTRY REG
**************************************
preserve
		//Country-Region(pair) Variable: Country level for Acq; Region level for Tgt
		gen Region_TGT =""
		replace Region_TGT ="North" if n1_tgt ==1
		replace Region_TGT ="South" if s1_tgt ==1
		gen Region_ACQ =""
		replace Region_ACQ ="North" if n1_acq ==1
		replace Region_ACQ ="South" if s1_acq ==1
		bysort acq Region_TGT year: egen value_total = sum(value), missing
		duplicates drop acq Region_TGT year value_total, force
		keep acq year gdp_acq Region_TGT value_total Region_ACQ
		rename Region_TGT tgt
		sort acq tgt year
		order acq tgt year value_total gdp_acq
		save "$Output\country_region_aux.dta" ,replace
restore
preserve
		//Region-Country(pair) Variable: Country level for Tgt; Region level for Acq
		gen Region_ACQ =""
		replace Region_ACQ ="North" if n1_acq ==1
		replace Region_ACQ ="South" if s1_acq ==1
		gen Region_TGT =""
		replace Region_TGT ="North" if n1_tgt ==1
		replace Region_TGT ="South" if s1_tgt ==1
		bysort tgt Region_ACQ year: egen value_total = sum(value), missing
		duplicates drop tgt Region_ACQ year value_total, force
		keep tgt year gdp_tgt Region_ACQ value_total Region_TGT
		rename Region_ACQ acq
		sort acq tgt year
		order acq tgt year value_total gdp_tgt
		
		//Appending Country-Region and Region-Country
		append using "$Output\country_region_aux.dta"
		erase "$Output\country_region_aux.dta"
		
	    //Merging with Region GDPs
		merge m:1 year using "$Input\regions_gdp.dta"
		keep if _merge ==3
		drop _merge
		keep acq tgt year value_total gdp_tgt gdp_acq Region_ACQ Region_TGT north_S_`x' north_R_`x' south_S_`x' south_R_`x'
		
		replace Region_TGT = tgt if Region_TGT ==""
		replace Region_ACQ = acq if Region_ACQ ==""
		order Region_TGT, after(Region_ACQ)
		order gdp_tgt, after(gdp_acq)
		
		*Use Country GDPs for Countries and REGION GDPs for REGIONs
		replace gdp_acq = north_S_`x' if acq =="North" & gdp_acq ==.
		replace gdp_tgt = north_R_`x' if tgt =="North" & gdp_tgt ==.
		replace gdp_acq = south_S_`x' if acq =="South" & gdp_acq ==.
		replace gdp_tgt = south_R_`x' if tgt =="South" & gdp_tgt ==.
		drop north_S_`x' north_R_`x' south_S_`x' south_R_`x'
		
*Deflating GDPs (given that I have already deflated the capital flows)
merge m:1 year using "$Input/PRICE_DEFLATOR.dta"
keep if _merge ==3
replace gdp_acq  = gdp_acq / deflator
replace gdp_tgt  = gdp_tgt / deflator
drop _merge deflator
			
sort acq tgt year
rename value_total value
order acq tgt year value gdp_acq gdp_tgt Region_ACQ Region_TGT 

*Creating Region-Region Dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if Region_ACQ =="North" & Region_TGT =="North"
replace ns=1 if Region_ACQ =="North" & Region_TGT =="South"
replace sn=1 if Region_ACQ =="South" & Region_TGT =="North"
replace ss=1 if Region_ACQ =="South" & Region_TGT =="South"		

///////////////////Adjusting for the jump ///////////////////
*Create interaction Region-Region dummies and post-2009 dummy
gen nn_post=0
gen ns_post=0
gen sn_post=0
gen ss_post=0
replace nn_post=1 if nn==1 & year>=2009
replace ns_post=1 if ns==1 & year>=2009
replace sn_post=1 if sn==1 & year>=2009
replace ss_post=1 if ss==1 & year>=2009	
////////////////////////////////////////////////////////////

*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j'
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

*Creating Country-Region dummies
gen country_dyad = acq+"_"+tgt
egen group = group(country_dyad)  //Country_dyad refers to the Country-Region (or Region-Country) pair.
xtset group year

*Creating dependent variable
gen l_value = log(value)

*Regressions
************
*1) Dependent Variable: Log(Value). Estimation method: OLS
areg l_value  nn ns sn ss  nn_post ns_post sn_post ss_post  nn_trend ns_trend sn_trend ss_trend, absorb(country_dyad) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 l_value  using "$Output\OAT3.xls", ctitle("OLS C-R log(value)") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-R R-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend) excel  
				 *We use the "keep" option because we don't want to export all the FE coefficients.

	 
*3) Dependent Variable: Value. Estimation method: PPML, with FE
xtpqml value  nn ns sn ss  nn_post ns_post sn_post ss_post  nn_trend ns_trend sn_trend ss_trend, fe i(group) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 value  using "$Output\OAT3.xls", ctitle("PPML FE C-R value") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-R R-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend) excel  

restore

**************************************
*COUNTRY-COUNTRY REG
**************************************

*Deflating Values (2011 USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
keep if _merge==3
replace gdp_acq = gdp_acq / deflator
replace gdp_tgt = gdp_tgt / deflator
label variable gdp_acq "Millions of 2011 USD"
label variable gdp_tgt "Millions of 2011 USD"
drop _merge deflator

///////////////////Adjusting for the jump ///////////////////
*Create interaction Region-Region dummies and post-2009 dummy
gen nn_post=0
gen ns_post=0
gen sn_post=0
gen ss_post=0
replace nn_post=1 if nn==1 & year>=2009
replace ns_post=1 if ns==1 & year>=2009
replace sn_post=1 if sn==1 & year>=2009
replace ss_post=1 if ss==1 & year>=2009	
////////////////////////////////////////////////////////////

*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' 
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

*Creating Country-Country dummies
drop country_dyad
gen country_dyad = acq+"_"+tgt
egen group = group(country_dyad)
xtset group year

*Creating dependent variable
gen l_value = log(value)
gen l_gdp_acq = log(gdp_acq)
gen l_gdp_tgt = log(gdp_tgt)


*Regressions
************
*1) Dependent Variable: Log(Value). Estimation method: OLS
*Country-pairs FE
areg l_value nn ns sn ss  nn_post ns_post sn_post ss_post  nn_trend ns_trend sn_trend ss_trend,  absorb(country_dyad) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 l_value  using "$Output\OAT3.xls", ctitle("OLS C-C log(value)") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend) excel  
								 

*3) Dependent Variable: Value. Estimation method: PPML, with FE
xtpqml value nn ns sn ss  nn_post ns_post sn_post ss_post  nn_trend ns_trend sn_trend ss_trend,  fe i(group) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 value  using "$Output\OAT3.xls", ctitle("PPML FE C-C value") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend) excel  
* Percentile GDP: average for all years, first year and last year
preserve
collapse (mean) gdp_acq1 = gdp_acq , by(acq)
xtile pct_gdp_s = gdp_acq1, n(5)
gen pct_gdp_s1 = pct_gdp_s // to merge with tgt
gen tgt = acq
save "$Output\aux_GDP_rank_s.dta", replace
restore

*Regressions
************
* Merging with sender and receiver positions
merge m:1 acq using "$Output\aux_GDP_rank_s.dta", nogen  keepus(pct_gdp_s)
merge m:1 tgt using "$Output\aux_GDP_rank_s.dta", nogen  keepus(pct_gdp_s1)

*3) Dependent Variable: Log(Value). Estimation method: OLS
local k = 5
reghdfe l_value  nn_trend ns_trend sn_trend ss_trend if pct_gdp_s1>=`k' & pct_gdp_s>=`k' ,  absorb(country_dyad) cluster(country_dyad)
            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 l_value  using "$Output\OAT3.xls", ctitle("OLS C-C log(value) `k'") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend  ) excel  

*4) Dependent Variable: Value. Estimation method: PPML, with FE
//xtpqml estimates ppml with fixed-effects
ppmlhdfe value  nn_trend ns_trend sn_trend ss_trend if pct_gdp_s>=`k' & pct_gdp_s1>=`k' , absorb(country_dyad) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 value  using "$Output\OAT3.xls", ctitle("PPML FE C-C value `k'") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend  ) excel  		

erase "$Output\auxx.dta"
erase "$Output\gdp_region_aux.dta"
erase "$Output\aux_GDP_rank_s.dta"			 


}
