/* *********************************************************************************************************************************************************************************************************************
This do file runs all the regressions for Online Appendix Table 4 - FDI: Extensive Margin Regressions Robustness.

We run T7 for FDI but, in this case, we account for the observed jump in the series in 2009, when we start to use IMF data
(in F2 we can see how the share of active connections jump in 2009)

To adjust for this jump, we add region-region dummies interacted with a dummy that is 1 from 2009 onwards

- In previous versions, we also tried other robustness (use a balanced sample and adding country-region dummies that can change from 2009 onwards). This is in older do files

************************************************************************************************************************************************************************************************************************* */

clear all
set more off
set matsize 11000
set maxvar 32767

local databases "FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear
sum year
scalar first_year= r(min)
scalar last_year= r(max)
scalar total_years= (last_year-first_year) + 1
keep if year>=`=scalar(first_year)' & year<=`=scalar(last_year)'

*Separating North and South countries (both exclude offshore centers)
// do "$Dofiles\North-South classification.do"
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*Creating region-pairs dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if n1_acq==1 & n1_tgt==1
replace ns=1 if n1_acq==1 & s1_tgt==1
replace sn=1 if s1_acq==1 & n1_tgt==1
replace ss=1 if s1_acq==1 & s1_tgt==1

**************************
*REGION-REGION REGRESSIONS
**************************

preserve

bysort year: egen count_NN=count(value) if value!=0 & n1_acq==1 & n1_tgt==1
bysort year: egen count_NS=count(value) if value!=0 & n1_acq==1 & s1_tgt==1
bysort year: egen count_SN=count(value) if value!=0 & s1_acq==1 & n1_tgt==1
bysort year: egen count_SS=count(value) if value!=0 & s1_acq==1 & s1_tgt==1
* The "count" fx does not count if the observation equals ".". It only counts non missing values.

collapse count_NN count_NS count_SN count_SS, by(year nn ns sn ss)

*Combine the different counts into a single variable
egen active_connections= rowtotal(count_NN count_NS count_SN count_SS), missing

drop count_NN count_NS count_SN count_SS

*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' //Note that the 1st year has trend==0.
	}	
	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

///////////////////Adjusting for the jump ///////////////////
*Create interaction Region-Region dummies and post-2009 dummy
gen nn_post=0
gen ns_post=0
gen sn_post=0
gen ss_post=0
replace nn_post=1 if nn==1 & year>=2009
replace ns_post=1 if ns==1 & year>=2009
replace sn_post=1 if sn==1 & year>=2009
replace ss_post=1 if ss==1 & year>=2009	
///////////////////////////////////////////////////////////////

*Regressions
*************
*1) Dependent Variable: Number of active connections. Estimation method: Poisson
poisson active_connections  nn ns sn ss  nn_post ns_post sn_post ss_post  nn_trend ns_trend sn_trend ss_trend

			* Wald tests
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
			outreg2 using "$Output\OAT4_RR-CR.xls", ctitle("R-R Pois Numb") ///
			addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R") ///
			bdec(3) cons keep(nn_trend ns_trend sn_trend ss_trend) excel replace

restore 

***************************
*COUNTRY-REGION REGRESSIONS
***************************

preserve

//Country-Region(pair) Variable: Country level for Acq; Region level for Tgt
		gen Region_TGT =""
		replace Region_TGT ="North" if n1_tgt ==1
		replace Region_TGT ="South" if s1_tgt ==1
		gen Region_ACQ =""
		replace Region_ACQ ="North" if n1_acq ==1
		replace Region_ACQ ="South" if s1_acq ==1
		*Number of Active Links
			gen value_aux = .
			replace value_aux =1 if value!=0 & value!=.  //this will give the number of active connections
			bysort acq Region_TGT year: egen active_connections =count(value_aux)
			
			*The problem with count is that count of all missings is zero. But we want the count of all missings to be missing.
			*First we create a dummy that equals 1 when the flow between a country-pair is zero.
			*Then, we group observations by region receiving, country sending and year. We count if inside this group there is an observation that equals zero.
			*Variable y is positive whenever there is a zero in the group, and it is zero if all the observations in the group are positive, positive and missings, or all missings.
			*Now we want to substitute by missings the active connections if the Region-country pair observations are all missing for a given year.
			*But we want to keep active_connections==0 if the observations are a combination of missings and zeros.
			gen x=.
			replace x=1 if value==0
			bysort acq Region_TGT year: egen y= count(x)
			replace active_connections=. if value==. & active_connections==0 & y==0 //Putting missing where they belong. Remember that some countries do not report
			
			duplicates drop acq Region_TGT year, force
			keep acq year Region_TGT active_connections Region_ACQ
			rename Region_TGT tgt
			sort acq tgt year
			order acq tgt year active_connections
			save "$Output\country_region_aux.dta",replace
			
restore
preserve
		//Region-Country(pair) Variable: Country level for Tgt; Region level for Acq
		gen Region_ACQ =""
		replace Region_ACQ ="North" if n1_acq ==1
		replace Region_ACQ ="South" if s1_acq ==1
		gen Region_TGT =""
		replace Region_TGT ="North" if n1_tgt ==1
		replace Region_TGT ="South" if s1_tgt ==1
		*Number of Active Links
			gen value_aux = .
			replace value_aux =1 if value!=0 & value!=.  //this will give me the number of active connections
			bysort tgt Region_ACQ year: egen active_connections =count(value_aux)
			
			* We conduct the same procedure as before to make sure when all values are missings, active connections is missing too
			gen x=.
			replace x=1 if value==0
			bysort tgt Region_ACQ year: egen y= count(x)
			replace active_connections=. if value==. & active_connections==0 & y==0 
			
			duplicates drop tgt Region_ACQ year, force
			keep tgt year Region_ACQ active_connections Region_TGT
			rename Region_ACQ acq
			sort acq tgt year
			order acq tgt year active_connections
		
		//Appending Country-Region and Region-Country
		append using "$Output\country_region_aux.dta"
		replace Region_TGT = tgt if Region_TGT ==""
		replace Region_ACQ = acq if Region_ACQ ==""
		erase "$Output\country_region_aux.dta"


*Creating Region-Region Dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if Region_ACQ =="North" & Region_TGT =="North"
replace ns=1 if Region_ACQ =="North" & Region_TGT =="South"
replace sn=1 if Region_ACQ =="South" & Region_TGT =="North"
replace ss=1 if Region_ACQ =="South" & Region_TGT =="South"	

///////////////////Adjusting for the jump ///////////////////
*Create interaction Region-Region dummies and post-2009 dummy
gen nn_post=0
gen ns_post=0
gen sn_post=0
gen ss_post=0
replace nn_post=1 if nn==1 & year>=2009
replace ns_post=1 if ns==1 & year>=2009
replace sn_post=1 if sn==1 & year>=2009
replace ss_post=1 if ss==1 & year>=2009	
////////////////////////////////////////////////////////////

*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' //Note that the 1st year has trend==0.
	}		
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend


*Creating Country-Region dummies
gen country_dyad = acq+"_"+tgt
egen group = group(country_dyad)  //Note 1: Country_dyad refers here to the country-Region pair.
qui tabulate group, gen(d_control) //These are the Country-Region Dummies.

*Regressions
*************

*1) Dependent Variable: Number of active connections. Estimation method: Poisson

poisson active_connections  nn ns sn ss  nn_post ns_post sn_post ss_post  d_control*  nn_trend ns_trend sn_trend ss_trend,  cluster(country_dyad)

			* Wald tests
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
			outreg2 using "$Output\OAT4_RR-CR.xls", ctitle("C-R Pois Numb") ///
			addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-R R-C") ///
			bdec(3) cons keep(nn_trend ns_trend sn_trend ss_trend) excel 

restore 

**************************************
*COUNTRY-COUNTRY REG
**************************************

*Creating NN, NS, SS, SN dummies (all categories in 1 factor variable)
gen dummy=.
replace dummy = 1 if n1_acq ==1 & n1_tgt==1  //NN
replace dummy = 2 if n1_acq ==1 & s1_tgt==1  //NS
replace dummy = 3 if s1_acq ==1 & n1_tgt==1  //SN
replace dummy = 4 if s1_acq ==1 & s1_tgt==1  //SS
label define dummies 1 "NN" 2"NS" 3 "SN" 4 "SS"
label values dummy dummies

///////////////////Adjusting for the jump ///////////////////
*Create post-2009 dummy
gen post=0
replace post=1 if year>=2009
////////////////////////////////////////////////////////////

*Creating Trend
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' //Note that the 1st year has trend==0.
	}

*Creating the dependent variable (1 if value>0 // O if value==0 // Missing if value==.)
gen ind_connections=0
replace ind_connections=1 if value!=0 & value!=.
replace ind_connections=. if value==. 

*1) Dependent Variable: Dummy indicating if connection is active or not. Estimation method: Logit, No FE

logit ind_connections i.dummy i.dummy#i.post i.dummy#c.trend , cluster(country_dyad) base 

estimates store logit_nofe

* For the Logit we want the average marginal effect, the base probability (trend=0), and predicted probabilities

//Average marginal effects for NN, NS, SN, SS (separately)
margins, dydx(trend) over(dummy) post
	
	// Wald Tests
	test 4.dummy = 1.dummy //SS = NN 
	local coef1= round(_b[4.dummy] - _b[1.dummy],0.001)
	local test1=r(p)
	test 3.dummy = 1.dummy //SN = NN
	local coef2= round(_b[3.dummy] - _b[1.dummy],0.001)
	local test2=r(p)
	test 2.dummy = 1.dummy //NS = NN 
	local coef3= round(_b[2.dummy] - _b[1.dummy],0.001)
	local test3=r(p)
	test 3.dummy = 2.dummy //SN = NS 
	local coef4= round(_b[3.dummy] - _b[2.dummy],0.001)
	local test4=r(p)
	test 4.dummy + 2.dummy = 1.dummy + 3.dummy //South as Receiver vs North as Receiver
	local coef5= round((_b[4.dummy]+_b[2.dummy] - _b[1.dummy] - _b[3.dummy])/2,0.001)
	local test5=r(p)				
	test 4.dummy + 3.dummy = 1.dummy + 2.dummy //South as Sender vs North as Sender
	local coef6= round((_b[4.dummy]+_b[3.dummy] - _b[1.dummy] - _b[2.dummy])/2,0.001)
	local test6=r(p)
	forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}
		outreg2 using "$Output\OAT4_CC.xls", ctitle("Logit AME")  ///
		addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4', "Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R") ///
		bdec(3) cons keep(1bn.dummy 2.dummy 3.dummy 4.dummy) excel

	// How to identify results in output
	// 1bn.at is the average marg effect for NN trend
	// 2.at is the average marg effect for NS trend
	// 2.at is the average marg effect for NS trend
	// 3.at is the average marg effect for SN trend
	// 4.at is the average marg effect for SS trend
		
//Base probabilities
estimates restore logit_nofe
* When we calculate the margin the logit regression results are erased. So we need to run the regression again.
 
margins, at(trend==0) over(dummy) post

	// Wald Tests
	test 4.dummy = 1.dummy //SS = NN 
	local coef1= round(_b[4.dummy] - _b[1.dummy],0.001)
	local test1=r(p)
	test 3.dummy = 1.dummy //SN = NN
	local coef2= round(_b[3.dummy] - _b[1.dummy],0.001)
	local test2=r(p)
	test 2.dummy = 1.dummy //NS = NN 
	local coef3= round(_b[2.dummy] - _b[1.dummy],0.001)
	local test3=r(p)
	test 3.dummy = 2.dummy //SN = NS 
	local coef4= round(_b[3.dummy] - _b[2.dummy],0.001)
	local test4=r(p)
	test 4.dummy + 2.dummy = 1.dummy + 3.dummy //South as Receiver vs North as Receiver
	local coef5= round((_b[4.dummy]+_b[2.dummy] - _b[1.dummy] - _b[3.dummy])/2,0.001)
	local test5=r(p)				
	test 4.dummy + 3.dummy = 1.dummy + 2.dummy //South as Sender vs North as Sender
	local coef6= round((_b[4.dummy]+_b[3.dummy] - _b[1.dummy] - _b[2.dummy])/2,0.001)
	local test6=r(p)		
	forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}

	outreg2 using "$Output\OAT4_CC.xls", ctitle("Logit Base Prob")  ///
	addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4', "Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R") ///
	bdec(3) cons keep(1bn.dummy 2.dummy 3.dummy 4.dummy) excel

	// How to identify results in output
	// 1bn.at is the average marg effect for NN trend
	// 2.at is the base predicted prob for NS trend
	// 2.at is the base predicted prob for NS trend
	// 3.at is the base predicted prob for SN trend
	// 4.at is the base predicted prob for SS trend

//Predicted probabilities
estimates restore logit_nofe
* When we calculate the margin the logit regression results are erased. So we need to run the regression again.

matrix M_`x' = J(`=scalar(total_years)',4,.) //Define matrix with YEARS in rows and 4 columns (NN NS SN SS). I will store the results here.
matrix colnames M_`x' = NN NS SN SS
forval l=1/`=scalar(total_years)' { //These are the rows. One for each year of the sample
local z =`l'-1  //Trend=0 for first year of each sample (that's why I rest 1)
quietly margins, at(trend=`z') over(dummy)
scalar m`l'1 = el(r(b),1,1)
scalar m`l'2 = el(r(b),1,2)
scalar m`l'3 = el(r(b),1,3)
scalar m`l'4 = el(r(b),1,4)
matrix M_`x'[`l',1] = m`l'1 //Inserting the predicted probabilities into the matrix.
matrix M_`x'[`l',2] = m`l'2
matrix M_`x'[`l',3] = m`l'3
matrix M_`x'[`l',4] = m`l'4
}

putexcel set "$Output\OAT4_Predicted Probabilites.xls", sheet(`x'_Logit, replace) modify
putexcel B1=matrix(M_`x'), colnames
clear matrix

// *2) Robusteness - Dependent Variable: Dummy indicating if connection is active or not. Estimation method: Logit FE
// *Using xtlogit, margins command is not calculating the AME and predicted probabilities (says it is not "estimable")
// *Not clear why this is happening
// *Instead, I use logit command and manually add the C-C dummies
//
// preserve
//
// egen group = group(country_dyad)
//
// *Too many country-pairs to generate dummies. We can reduce groups by excluding obs with no variation
// *FE logit drops obs with no variation
// bysort country_dyad: egen aux1=min(ind_connections)
// bysort country_dyad: egen aux2=max(ind_connections)
// drop if aux1==aux2 //Drops obs within country pair that are all zeros, all 1s, or all missings
// drop aux1 aux2 
//
// qui tab country_dyad, gen(country_pairs)  
//
// logit ind_connections i.dummy i.dummy#i.post i.dummy#c.trend country_pairs*, robust
//
// estimates store logit_fe
//
// //Average marginal effects for NN, NS, SN, SS (separately)
// margins, dydx(trend) over(dummy) post
//	
// 	// Wald Tests
// 	test 4.dummy = 1.dummy //SS = NN 
// 	local coef1= round(_b[4.dummy] - _b[1.dummy],0.001)
// 	local test1=r(p)
// 	test 3.dummy = 1.dummy //SN = NN
// 	local coef2= round(_b[3.dummy] - _b[1.dummy],0.001)
// 	local test2=r(p)
// 	test 2.dummy = 1.dummy //NS = NN 
// 	local coef3= round(_b[2.dummy] - _b[1.dummy],0.001)
// 	local test3=r(p)
// 	test 3.dummy = 2.dummy //SN = NS 
// 	local coef4= round(_b[3.dummy] - _b[2.dummy],0.001)
// 	local test4=r(p)
// 	test 4.dummy + 2.dummy = 1.dummy + 3.dummy //South as Receiver vs North as Receiver
// 	local coef5= round((_b[4.dummy]+_b[2.dummy] - _b[1.dummy] - _b[3.dummy])/2,0.001)
// 	local test5=r(p)				
// 	test 4.dummy + 3.dummy = 1.dummy + 2.dummy //South as Sender vs North as Sender
// 	local coef6= round((_b[4.dummy]+_b[3.dummy] - _b[1.dummy] - _b[2.dummy])/2,0.001)
// 	local test6=r(p)
// 	forvalues h=1(1)6{
// 			if `test`h''<0.01{
// 			local star`h' "***"
// 			}
// 			if `test`h''>0.01 & `test`h''<0.05{
// 			local star`h' "**"
// 			}
// 			if `test`h''>0.05 & `test`h''<0.1{
// 			local star`h' "*"
// 			}
// 			if `test`h''>0.1 {
// 			local star`h' ""
// 			}
// 			}
// 		outreg2 using "$Output\T8_CC.xls", ctitle("Logit FE AME")  ///
// 		addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4', "Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") ///
// 		bdec(3) cons keep(1bn.dummy 2.dummy 3.dummy 4.dummy) excel
//
// 	// How to identify results in output
// 	// 1bn.at is the average marg effect for NN trend
// 	// 2.at is the average marg effect for NS trend
// 	// 2.at is the average marg effect for NS trend
// 	// 3.at is the average marg effect for SN trend
// 	// 4.at is the average marg effect for SS trend
//		
// //Base probabilities
// estimates restore logit_fe
// * When we calculate the margin the logit regression results are erased. So we need to run the regression again.
// 
// margins, at(trend==0) over(dummy) post
//
// 	// Wald Tests
// 	test 4.dummy = 1.dummy //SS = NN 
// 	local coef1= round(_b[4.dummy] - _b[1.dummy],0.001)
// 	local test1=r(p)
// 	test 3.dummy = 1.dummy //SN = NN
// 	local coef2= round(_b[3.dummy] - _b[1.dummy],0.001)
// 	local test2=r(p)
// 	test 2.dummy = 1.dummy //NS = NN 
// 	local coef3= round(_b[2.dummy] - _b[1.dummy],0.001)
// 	local test3=r(p)
// 	test 3.dummy = 2.dummy //SN = NS 
// 	local coef4= round(_b[3.dummy] - _b[2.dummy],0.001)
// 	local test4=r(p)
// 	test 4.dummy + 2.dummy = 1.dummy + 3.dummy //South as Receiver vs North as Receiver
// 	local coef5= round((_b[4.dummy]+_b[2.dummy] - _b[1.dummy] - _b[3.dummy])/2,0.001)
// 	local test5=r(p)				
// 	test 4.dummy + 3.dummy = 1.dummy + 2.dummy //South as Sender vs North as Sender
// 	local coef6= round((_b[4.dummy]+_b[3.dummy] - _b[1.dummy] - _b[2.dummy])/2,0.001)
// 	local test6=r(p)		
// 	forvalues h=1(1)6{
// 			if `test`h''<0.01{
// 			local star`h' "***"
// 			}
// 			if `test`h''>0.01 & `test`h''<0.05{
// 			local star`h' "**"
// 			}
// 			if `test`h''>0.05 & `test`h''<0.1{
// 			local star`h' "*"
// 			}
// 			if `test`h''>0.1 {
// 			local star`h' ""
// 			}
// 			}
//
// 	outreg2 using "$Output\T8_CC.xls", ctitle("Logit FE Base Prob")  ///
// 	addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4', "Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") ///
// 	bdec(3) cons keep(1bn.dummy 2.dummy 3.dummy 4.dummy) excel
//
// 	// How to identify results in output
// 	// 1bn.at is the average marg effect for NN trend
// 	// 2.at is the base predicted prob for NS trend
// 	// 2.at is the base predicted prob for NS trend
// 	// 3.at is the base predicted prob for SN trend
// 	// 4.at is the base predicted prob for SS trend
//
// //Predicted probabilities
// estimates restore logit_fe
// * When we calculate the margin the logit regression results are erased. So we need to run the regression again.
//
// matrix M_`x' = J(`=scalar(total_years)',4,.) //Define matrix with YEARS in rows and 4 columns (NN NS SN SS). I will store the results here.
// matrix colnames M_`x' = NN NS SN SS
// forval l=1/`=scalar(total_years)' { //These are the rows. One for each year of the sample
// local z =`l'-1  //Trend=0 for first year of each sample (that's why I rest 1)
// quietly margins, at(trend=`z') over(dummy)
// scalar m`l'1 = el(r(b),1,1)
// scalar m`l'2 = el(r(b),1,2)
// scalar m`l'3 = el(r(b),1,3)
// scalar m`l'4 = el(r(b),1,4)
// matrix M_`x'[`l',1] = m`l'1 //Inserting the predicted probabilities into the matrix.
// matrix M_`x'[`l',2] = m`l'2
// matrix M_`x'[`l',3] = m`l'3
// matrix M_`x'[`l',4] = m`l'4
// }
//
// putexcel set "$Output\T8_Predicted Probabilites.xls", sheet(`x'_Logit_FE, replace) modify
// putexcel B1=matrix(M_`x'), colnames
// clear matrix
//	
// restore
//
// *3) Robustness - Dependent Variable: Dummy indicating if connection is active or not. Estimation method: Logit, Gravity Controls
//
// logit ind_connections i.dummy i.dummy#i.post i.dummy#c.trend time comlegal cu colony comlang dist border d_lat d_long, cluster(country_dyad) base 
//
// estimates store logit_gc
//
// * For the Logit we want the average marginal effect, the base probability (trend=0), and predicted probabilities
//
// //Average marginal effects for NN, NS, SN, SS (separately)
// margins, dydx(trend) over(dummy) post
//	
// 	// Wald Tests
// 	test 4.dummy = 1.dummy //SS = NN 
// 	local coef1= round(_b[4.dummy] - _b[1.dummy],0.001)
// 	local test1=r(p)
// 	test 3.dummy = 1.dummy //SN = NN
// 	local coef2= round(_b[3.dummy] - _b[1.dummy],0.001)
// 	local test2=r(p)
// 	test 2.dummy = 1.dummy //NS = NN 
// 	local coef3= round(_b[2.dummy] - _b[1.dummy],0.001)
// 	local test3=r(p)
// 	test 3.dummy = 2.dummy //SN = NS 
// 	local coef4= round(_b[3.dummy] - _b[2.dummy],0.001)
// 	local test4=r(p)
// 	test 4.dummy + 2.dummy = 1.dummy + 3.dummy //South as Receiver vs North as Receiver
// 	local coef5= round((_b[4.dummy]+_b[2.dummy] - _b[1.dummy] - _b[3.dummy])/2,0.001)
// 	local test5=r(p)				
// 	test 4.dummy + 3.dummy = 1.dummy + 2.dummy //South as Sender vs North as Sender
// 	local coef6= round((_b[4.dummy]+_b[3.dummy] - _b[1.dummy] - _b[2.dummy])/2,0.001)
// 	local test6=r(p)
// 	forvalues h=1(1)6{
// 			if `test`h''<0.01{
// 			local star`h' "***"
// 			}
// 			if `test`h''>0.01 & `test`h''<0.05{
// 			local star`h' "**"
// 			}
// 			if `test`h''>0.05 & `test`h''<0.1{
// 			local star`h' "*"
// 			}
// 			if `test`h''>0.1 {
// 			local star`h' ""
// 			}
// 			}
// 		outreg2 using "$Output\T8_CC.xls", ctitle("Logit GC AME")  ///
// 		addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4', "Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R + GC") ///
// 		bdec(3) cons keep(1bn.dummy 2.dummy 3.dummy 4.dummy) excel
//
// 	// How to identify results in output
// 	// 1bn.at is the average marg effect for NN trend
// 	// 2.at is the average marg effect for NS trend
// 	// 2.at is the average marg effect for NS trend
// 	// 3.at is the average marg effect for SN trend
// 	// 4.at is the average marg effect for SS trend
//		
// //Base probabilities
// estimates restore logit_gc
// * When we calculate the margin the logit regression results are erased. So we need to run the regression again.
// 
// margins, at(trend==0) over(dummy) post
//
// 	// Wald Tests
// 	test 4.dummy = 1.dummy //SS = NN 
// 	local coef1= round(_b[4.dummy] - _b[1.dummy],0.001)
// 	local test1=r(p)
// 	test 3.dummy = 1.dummy //SN = NN
// 	local coef2= round(_b[3.dummy] - _b[1.dummy],0.001)
// 	local test2=r(p)
// 	test 2.dummy = 1.dummy //NS = NN 
// 	local coef3= round(_b[2.dummy] - _b[1.dummy],0.001)
// 	local test3=r(p)
// 	test 3.dummy = 2.dummy //SN = NS 
// 	local coef4= round(_b[3.dummy] - _b[2.dummy],0.001)
// 	local test4=r(p)
// 	test 4.dummy + 2.dummy = 1.dummy + 3.dummy //South as Receiver vs North as Receiver
// 	local coef5= round((_b[4.dummy]+_b[2.dummy] - _b[1.dummy] - _b[3.dummy])/2,0.001)
// 	local test5=r(p)				
// 	test 4.dummy + 3.dummy = 1.dummy + 2.dummy //South as Sender vs North as Sender
// 	local coef6= round((_b[4.dummy]+_b[3.dummy] - _b[1.dummy] - _b[2.dummy])/2,0.001)
// 	local test6=r(p)		
// 	forvalues h=1(1)6{
// 			if `test`h''<0.01{
// 			local star`h' "***"
// 			}
// 			if `test`h''>0.01 & `test`h''<0.05{
// 			local star`h' "**"
// 			}
// 			if `test`h''>0.05 & `test`h''<0.1{
// 			local star`h' "*"
// 			}
// 			if `test`h''>0.1 {
// 			local star`h' ""
// 			}
// 			}
//
// 	outreg2 using "$Output\T8_CC.xls", ctitle("Logit GC Base Prob")  ///
// 	addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4', "Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R + GC") ///
// 	bdec(3) cons keep(1bn.dummy 2.dummy 3.dummy 4.dummy) excel
//
// 	// How to identify results in output
// 	// 1bn.at is the average marg effect for NN trend
// 	// 2.at is the base predicted prob for NS trend
// 	// 2.at is the base predicted prob for NS trend
// 	// 3.at is the base predicted prob for SN trend
// 	// 4.at is the base predicted prob for SS trend
//
// //Predicted probabilities
// estimates restore logit_gc
// * When we calculate the margin the logit regression results are erased. So we need to run the regression again.
//
// matrix M_`x' = J(`=scalar(total_years)',4,.) //Define matrix with YEARS in rows and 4 columns (NN NS SN SS). I will store the results here.
// matrix colnames M_`x' = NN NS SN SS
// forval l=1/`=scalar(total_years)' { //These are the rows. One for each year of the sample
// local z =`l'-1  //Trend=0 for first year of each sample (that's why I rest 1)
// quietly margins, at(trend=`z') over(dummy)
// scalar m`l'1 = el(r(b),1,1)
// scalar m`l'2 = el(r(b),1,2)
// scalar m`l'3 = el(r(b),1,3)
// scalar m`l'4 = el(r(b),1,4)
// matrix M_`x'[`l',1] = m`l'1 //Inserting the predicted probabilities into the matrix.
// matrix M_`x'[`l',2] = m`l'2
// matrix M_`x'[`l',3] = m`l'3
// matrix M_`x'[`l',4] = m`l'4
// }
//
// putexcel set "$Output\T8_Predicted Probabilites.xls", sheet(`x'_Logit_GC, replace) modify
// putexcel B1=matrix(M_`x'), colnames
// clear matrix
	
	
}
