/* **********************************************************************************************************************************************************************************************
This do file generates the input for T5: Intensive Margin over Regional GDP

In particular, for each region-pair (NN, NS, SN, and SS) we calculate 2 things:
	1) Investments/Regional GDP

We calculate this for first year, 2007, 2008, 2009, and last year
	
Note that we do not deflate prices, given that we will report ratios and not absolute values

The data for international reserves has a different structure so we treat it separately:
- It is as the C-R level (we don't have receiver countries)
- We already identified N and S countries
********************************************************************************************************************************************************************************************** */

clear all
set more off

***************
* IBS, CPIS and FDI
***************

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
egen first_year= min(year)
egen last_year=max(year)

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*Investments between regions by year
bysort year: egen World_value=sum(value)
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1


collapse (min) World_value NN_value NS_value SN_value SS_value first_year last_year, by(year)

*Merging with GDP
merge 1:1 year using "$Input\regions_gdp.dta"
keep if _merge ==3 //The merge is by region, not country. Therefore _merge ==3, except if the year is not included in the main database. We are not dropping obs here.
drop _merge

* 1. Investment/World GDP
*************************
// We use world receivers GDP (instead of world senders GDP). All senders are also receivers in our sample. So, by using the GDP of all receivers we are considering the GDP of all countries that participate in a region's cross-border flows
gen NN_WorldGDP = NN_value / sqrt(north_S_`x'*north_R_`x')
gen NS_WorldGDP = NS_value / sqrt(north_S_`x'*south_R_`x')
gen SN_WorldGDP = SN_value / sqrt(south_S_`x'*north_R_`x')
gen SS_WorldGDP = SS_value / sqrt(south_S_`x'*south_R_`x')

**********************************
*Presenting the Results 
**********************************
keep if year==first_year | year==last_year | year==2007 | year==2008 | year==2009
order year, first
keep year NN_WorldGDP-SS_WorldGDP
export excel using "$Output\T5.xlsx", sheet(`x') sheetreplace firstrow(variables)

}

**************
*Int. Reserves
**************
use "$Input\_IR.dta" ,clear 

egen first_year= min(year)
egen last_year=max(year)

*IR dataset already identifies region of acq country
*We exclude Offshore Centers as senders (we don't have receiver countries for IR)
drop if OFC_acq ==1
drop OFC_acq

*Investments between regions by year
bysort year: egen World_value=sum(value)
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1

collapse (min) World_value NN_value NS_value SN_value SS_value first_year last_year, by(year)

*Merging with GDP
merge 1:1 year using "$Input\regions_gdp.dta"
keep if _merge ==3 //The merge is by region, not country. Therefore _merge ==3, except if the year is not included in the main database. We are not dropping obs here.
drop _merge

* 1. Investment/World GDP
*************************
/*In contrast to FDI and CPIS, we don't have a world receiver GDP so we use the world sender GDP
This is not a problem since for reserves we presume there are many senders and few receivers
Receivers will usually be a few very large countries which are also senders (US, UK, China, etc.) 
So even if we take world sender GDP we are considering the GDP of all countries that participate in cross-border reserves transactions
*/

gen NN_WorldGDP = NN_value / sqrt(north_S_IR*north_S_IR)
gen NS_WorldGDP = NS_value / sqrt(north_S_IR*south_S_IR)
gen SN_WorldGDP = SN_value / sqrt(south_S_IR*north_S_IR)
gen SS_WorldGDP = SS_value / sqrt(south_S_IR*south_S_IR)

**********************************
*Presenting the Results 
**********************************
keep if year==first_year | year==last_year | year==2007 | year==2008 | year==2009
order year, first
keep year NN_WorldGDP-SS_WorldGDP
export excel using "$Output\T5.xlsx", sheet(IR) sheetreplace firstrow(variables)
