/* *********************************************************************************************************************************************************************************************************************
This do file runs all the regressions for Table 6 - Intensive Margin Regressions over Regional GDP

IR database has a different format and is at the Country-Region level so we treat it separately from CPIS and FDI

For CPIS and FDI:
The regressions use Region-Region, Country-Region, and Country-Country observations. Therefore, this dofile first creates new datasets with this level of aggregation.
The region-country regressions include both "Region-Country" and "Country-Region" observations 
We exclude offshore centers. All values are divided by Regional GDP (i,e, square root of (GDP sender * GDP receiver)), taking into account the corresponding level of aggregation (C-C, C-R & R-C, C-C)

For the Region-Region case, we run OLS regressions. These are the specifications:
1)  OLS: log(new_value) =   nn ns sn ss  nn_trend ns_trend  sn_trend ss_trend,  robust

For the Country-Region case, we run OLS and PPML regressions. These are the specifications:
1)  OLS: log(new_value) =  (Country-Region Dummies)  nn ns sn ss  nn_trend ns_trend  sn_trend ss_trend, cluster(Country-Region)
* Previous version
2)  PPML: new_value =   nn ns sn ss   nn_trend ns_trend sn_trend ss_trend, cluster(Country-Region)
3)  PPML FE: new_value =  (Country-Region Dummies)  nn ns sn ss  nn_trend ns_trend sn_trend ss_trend, cluster(Country-Region)

For the Country-Country case, we run OLS and PPML regressions. These are the specifications:
1)  OLS: log(new_value) =  (Country-Country Dummies) nn ns sn ss  nn_trend ns_trend sn_trend ss_trend, nocons cluster(Country-Country)
2)  PPML FE: new_value =  (Country-Country Dummies) nn ns sn ss  nn_trend ns_trend  sn_trend ss_trend, cluster(Country-Country)
* Previous version
3)  PPML: new_value =   nn ns sn ss   nn_trend ns_trend sn_trend ss_trend, cluster(Country-Country)
4)  PPML GC =  (Gravity Controls) nn ns sn ss   nn_trend ns_trend sn_trend ss_trend , cluster(Country-Country)

*New versions
We run the equations (1) and (2) restricting the sample to 5th quintile of average GDP by sender and receiver positions. 

For IR: We only run the R-R and C-R regressions. All values are divided by Regional GDP (i,e, square root of (GDP sender * GDP receiver)), taking into account the corresponding level of aggregation (C-C, C-R)

We are not reporting all of these results, but I keep them so we can reference in the text if needed
We only report:
R-R: OLS
C-R: OLS and PPML FE (PPML yield very similar results to PPML FE)
C-C: OLS, PPML, and PPML FE (PPML GC yield very similar results to PPML)

*General Notes:
-Given that in the regresions we use nominal values, we do deflate prices and reescale everything to 2011 USD
-The difference between PPML and PPML FE  is that, in the latter, obs with no variation across pairs (i.e. obs that are always zero)are dropped. 
We calculate PPML FE  despite this because we still want to control for time-invariant characteristics across pairs
-At the beginning of the code, you'll see that negative values are turned to missing and, hence, are dropped from the regressions. This is needed because PPML does not work
with negative values
-In a previous version, we also calculated the regressions using value/GDP. I left the codes to merge and format GDP data, just in case it is needed in the future .
-In a previous version, we were reporting the R2. To do this, we saved all the R2 in matrices. Also, we had to use a different command for the PPML (the one we use here does not report it), 
which was very slow and needed some adjustments before running. In older versions you can see the code to obtain the R2.
************************************************************************************************************************************************************************************************************************* */

clear all
set more off
set matsize 11000
set maxvar 32767

***************
* IBS, CPIS and FDI
***************

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
replace value=. if value<0 //PPML does not work with negative values
// replace value=0 if value<0 //PPML does not work with negative values, what's happened if we change these values to zero (instead of missing value)? Nothing, there're few obs with respecto to the total sample.
sum year
scalar first_year= r(min)
scalar last_year= r(max)
scalar total_years= (last_year-first_year) + 1
keep if year>=`=scalar(first_year)' & year<=`=scalar(last_year)'

*Deflating prices (2011 millions USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
drop if _merge != 3
replace value = value / deflator
label variable value "2011 Millions, USD"
drop _merge deflator

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*Creating region-pairs dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if n1_acq==1 & n1_tgt==1
replace ns=1 if n1_acq==1 & s1_tgt==1
replace sn=1 if s1_acq==1 & n1_tgt==1
replace ss=1 if s1_acq==1 & s1_tgt==1

**************************
*REGION-REGION REGRESSIONS
**************************
preserve
egen sum=sum(value), missing by(year nn ns sn ss)
collapse (max) sum, by(year nn ns sn ss)
rename sum value
gen l_value  = log(value) 
save "$Output\auxx.dta" , replace

*Merging with GDPs
	*Working first with the GDP database, to match the format
    use "$Input\regions_gdp.dta", clear
	keep year north_S_`x' north_R_`x' south_S_`x' south_R_`x'
	
	expand 4, gen(duplicate)
	*duplicate==1 if the observation is duplicated and 0 if it was originally in the dataset.
	egen group= group(year)
	sort group
	by group: gen count= _n
	sort count year
	gen nn=0
	g ns=0
	g sn=0
	g ss=0
	replace nn=1 if count==1
	replace ns=1 if count==2
	replace sn=1 if count==3
	replace ss=1 if count==4
	
	gen Gdp_Avg =0
	replace Gdp_Avg=  sqrt(north_S_`x'*north_R_`x') if nn==1
	replace Gdp_Avg=  sqrt(north_S_`x'*south_R_`x') if ns==1
	replace Gdp_Avg=  sqrt(south_S_`x'*north_R_`x') if sn==1
	replace Gdp_Avg=  sqrt(south_S_`x'*south_R_`x') if ss==1
	keep year nn ns sn ss Gdp_Avg north_S_`x' north_R_`x' south_S_`x' south_R_`x'
	
	*Deflating GDPs (given that I deflated flows before)
    merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
	keep if _merge ==3
	replace Gdp_Avg = Gdp_Avg / deflator
	gen norte_R_`x' = north_R_`x' / deflator
	gen norte_S_`x' = north_S_`x' / deflator
	gen sur_R_`x' = south_R_`x' / deflator
	gen sur_S_`x' = south_S_`x' / deflator
	label variable Gdp_Avg "Millions of 2011 USD"
	drop _merge deflator
	save "$Output\gdp_region_aux.dta", replace

use "$Output\auxx.dta", clear
merge 1:1 year nn ns sn ss using "$Output\gdp_region_aux.dta"
keep if _merge ==3 //The merge is by region, not country. Therefore _merge always equals 3, except if the year is not included in the main database. We are not dropping obs here.
drop _merge

*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' //Note that the 1st year has trend==0.
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

*Creating log GDP by acq or tgt
gen n1_acq = (nn==1 | ns == 1)
gen s1_acq = (sn==1 | ss == 1)
gen n1_tgt = (nn==1 | sn == 1)
gen s1_tgt = (ns==1 | ss == 1)

gen gdp_acq = norte_S_`x' if n1_acq ==1
replace gdp_acq = sur_S_`x' if s1_acq ==1 
gen gdp_tgt = norte_R_`x' if n1_tgt ==1 
replace gdp_tgt = sur_R_`x' if s1_tgt ==1 

* Generate value /sqrt(GDPsender * GDPreceiver)
gen l_gdp_avg = log(sqrt(gdp_acq*gdp_tgt))
gen nn_value = l_value - l_gdp_avg

*Regressions
*************
*1) Dependent Variable: Log(Value). Estimation method: OLS
reg nn_value  nn ns sn ss  nn_trend ns_trend sn_trend ss_trend  , robust
*When using the "nocons" option the estimates for the coefficients are exactly the same but the R-squared (and Adjusted R-squared) changes.
*This is because Stata is assuming that we are forcing our constant to be zero.
*Therefore, it is better to include all the constants and allow Stata to drop one of them because of multicollinearity. Another option is to use "hasconstant" to make Stata know that one of the dummies is the constant.
*Unless we want to report the coefficients for the dummies (and not just the interactions with the trend).

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
			outreg2 nn_value using "$Output\T6_`x'.xls", ctitle("OLS R-R log(value)") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3',"SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R") ///
				 keep(nn_trend ns_trend sn_trend ss_trend) bdec(3) excel replace
restore

**************************************
*COUNTRY-REGION and REGION-COUNTRY REG
**************************************

preserve
		//Country-Region(pair) Variable: Country level for Acq; Region level for Tgt
		gen Region_TGT =""
		replace Region_TGT ="North" if n1_tgt ==1
		replace Region_TGT ="South" if s1_tgt ==1
		gen Region_ACQ =""
		replace Region_ACQ ="North" if n1_acq ==1
		replace Region_ACQ ="South" if s1_acq ==1
		bysort acq Region_TGT year: egen value_total = sum(value), missing
		duplicates drop acq Region_TGT year value_total, force
		keep acq year gdp_acq Region_TGT value_total Region_ACQ
		rename Region_TGT tgt
		sort acq tgt year
		order acq tgt year value_total gdp_acq
		save "$Output\country_region_aux.dta" ,replace
restore
preserve
		//Region-Country(pair) Variable: Country level for Tgt; Region level for Acq
		gen Region_ACQ =""
		replace Region_ACQ ="North" if n1_acq ==1
		replace Region_ACQ ="South" if s1_acq ==1
		gen Region_TGT =""
		replace Region_TGT ="North" if n1_tgt ==1
		replace Region_TGT ="South" if s1_tgt ==1
		bysort tgt Region_ACQ year: egen value_total = sum(value), missing
		duplicates drop tgt Region_ACQ year value_total, force
		keep tgt year gdp_tgt Region_ACQ value_total Region_TGT
		rename Region_ACQ acq
		sort acq tgt year
		order acq tgt year value_total gdp_tgt
		
		//Appending Country-Region and Region-Country
		append using "$Output\country_region_aux.dta"
		erase "$Output\country_region_aux.dta"
		
		
	    //Merging with Region GDPs
		merge m:1 year using "$Input\regions_gdp.dta"
		keep if _merge ==3
		drop _merge
		keep acq tgt year value_total gdp_tgt gdp_acq Region_ACQ Region_TGT north_S_`x' north_R_`x' south_S_`x' south_R_`x'
		
		replace Region_TGT = tgt if Region_TGT ==""
		replace Region_ACQ = acq if Region_ACQ ==""
		order Region_TGT, after(Region_ACQ)
		order gdp_tgt, after(gdp_acq)
		
		*Use Country GDPs for Countries and REGION GDPs for REGIONs
		replace gdp_acq = north_S_`x' if acq =="North" & gdp_acq ==.
		replace gdp_tgt = north_R_`x' if tgt =="North" & gdp_tgt ==.
		replace gdp_acq = south_S_`x' if acq =="South" & gdp_acq ==.
		replace gdp_tgt = south_R_`x' if tgt =="South" & gdp_tgt ==.
		drop north_S_`x' north_R_`x' south_S_`x' south_R_`x'
		
*Deflating GDPs (given that I have already deflated the capital flows)
merge m:1 year using "$Input/PRICE_DEFLATOR.dta"
keep if _merge ==3
replace gdp_acq  = gdp_acq / deflator
replace gdp_tgt  = gdp_tgt / deflator
drop _merge deflator
			
sort acq tgt year
rename value_total value
order acq tgt year value gdp_acq gdp_tgt Region_ACQ Region_TGT 

*Creating Region-Region Dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if Region_ACQ =="North" & Region_TGT =="North"
replace ns=1 if Region_ACQ =="North" & Region_TGT =="South"
replace sn=1 if Region_ACQ =="South" & Region_TGT =="North"
replace ss=1 if Region_ACQ =="South" & Region_TGT =="South"		
			
*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j'
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

*Creating Country-Region dummies
gen country_dyad = acq+"_"+tgt
egen group = group(country_dyad)  //Country_dyad refers to the Country-Region (or Region-Country) pair.
xtset group year

gen l_value = log(value)

*New dependient variables
gen ll_gdp_mult = log(sqrt(gdp_acq * gdp_tgt))
gen nn_value = l_value - ll_gdp_mult
gen n_value = (value/sqrt(gdp_acq * gdp_tgt))

*Regressions
************
*1) Dependent Variable: Log(Value). Estimation method: OLS
reghdfe nn_value  nn_trend ns_trend sn_trend ss_trend, absorb(country_dyad) cluster(country_dyad)
            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 nn_value  using "$Output\T6_`x'.xls", ctitle("OLS C-R log(value)") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-R R-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend  )  excel  
				 *We use the "keep" option because we don't want to export all the FE coefficients.
restore

**************************************
*COUNTRY-COUNTRY REG
**************************************

*Deflating Values (2011 USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
keep if _merge==3
replace gdp_acq = gdp_acq / deflator
replace gdp_tgt = gdp_tgt / deflator
label variable gdp_acq "Millions of 2011 USD"
label variable gdp_tgt "Millions of 2011 USD"
drop _merge deflator
		
*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' 
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

*Creating Country-Country dummies
drop country_dyad
gen country_dyad = acq+"_"+tgt
egen group = group(country_dyad)
xtset group year

*Creating the dependent variable
gen l_value = log(value)
gen n_value = value /sqrt(gdp_acq * gdp_tgt)
gen nn_value = log(n_value)

*Regressions
************
*1) Dependent Variable: Log(Value). Estimation method: OLS
reghdfe nn_value  nn_trend ns_trend sn_trend ss_trend,  absorb(country_dyad) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 nn_value  using "$Output\T6_`x'.xls", ctitle("OLS C-C log(value)") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend  ) excel  


*2) Dependent Variable: Value. Estimation method: PPML, with FE
//xtpqml estimates ppml with fixed-effects
ppmlhdfe n_value  nn_trend ns_trend sn_trend ss_trend, absorb(country_dyad) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 n_value  using "$Output\T6_`x'.xls", ctitle("PPML FE C-C value") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend  ) excel  
				 
* Percentile GDP: average for all years, first year and last year
preserve
collapse (mean) gdp_acq1 = gdp_acq , by(acq)
xtile pct_gdp_s = gdp_acq1, n(5)
gen pct_gdp_s1 = pct_gdp_s // to merge with tgt
gen tgt = acq
save "$Output\aux_GDP_rank_s.dta", replace
restore

*Regressions
************
merge m:1 acq using "$Output\aux_GDP_rank_s.dta", nogen  keepus(pct_gdp_s)
merge m:1 tgt using "$Output\aux_GDP_rank_s.dta", nogen  keepus(pct_gdp_s1)

*3) Dependent Variable: Log(New Value). Estimation method: OLS
local k = 5
reghdfe nn_value  nn_trend ns_trend sn_trend ss_trend if pct_gdp_s1>=`k' & pct_gdp_s>=`k' ,  absorb(country_dyad) cluster(country_dyad)
            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 nn_value  using "$Output\T6_`x'.xls", ctitle("OLS C-C log(value) `k'") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend  ) excel  

*4) Dependent Variable: New Value. Estimation method: PPML, with FE
//xtpqml estimates ppml with fixed-effects
ppmlhdfe n_value  nn_trend ns_trend sn_trend ss_trend if pct_gdp_s>=`k' & pct_gdp_s1>=`k' , absorb(country_dyad) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 n_value  using "$Output\T6_`x'.xls", ctitle("PPML FE C-C value `k'") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend  ) excel  		

erase "$Output\auxx.dta"
erase "$Output\gdp_region_aux.dta"
erase "$Output\aux_GDP_rank_s.dta"
}



////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

***************
* Int. Reserves
***************
local databases "IR"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
replace value=. if value<0 //Since we are running for PPML this is not necessary, but I keep it to be consistent with CPIS and FDI regressions
sum year
scalar first_year= r(min)
scalar last_year= r(max)
scalar total_years= (last_year-first_year) + 1
keep if year>=`=scalar(first_year)' & year<=`=scalar(last_year)'

*Deflating prices (2011 millions USD)
merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
drop if _merge != 3
replace value = value / deflator
label variable value "2011 Millions, USD"
drop _merge deflator

*We exclude Offshore Centers as senders
drop if OFC_acq ==1
drop OFC_acq

*Creating region-pairs dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if n1_acq==1 & n1_tgt==1
replace ns=1 if n1_acq==1 & s1_tgt==1
replace sn=1 if s1_acq==1 & n1_tgt==1
replace ss=1 if s1_acq==1 & s1_tgt==1


**************************
*REGION-REGION REGRESSIONS
**************************
preserve
egen sum=sum(value), missing by(year nn ns sn ss)
collapse (max) sum, by(year nn ns sn ss)
rename sum value
gen l_value  = log(value) 
save "$Output\auxx.dta" , replace

*Merging with GDPs
	*Working first with the GDP database, to match the format
    use "$Input\regions_gdp.dta", clear
	keep year north_S_`x' south_S_`x' 
	
	expand 4, gen(duplicate)
	*duplicate==1 if the observation is duplicated and 0 if it was originally in the dataset.
	egen group= group(year)
	sort group
	by group: gen count= _n
	sort count year
	gen nn=0
	g ns=0
	g sn=0
	g ss=0
	replace nn=1 if count==1
	replace ns=1 if count==2
	replace sn=1 if count==3
	replace ss=1 if count==4
	
	*Deflating GDPs (given that I deflated flows before)
    merge m:1 year using "$Input\PRICE_DEFLATOR.dta"
	keep if _merge ==3


// 	gen norte_R_`x' = north_R_`x' / deflator
	gen norte_S_`x' = north_S_`x' / deflator
// 	gen sur_R_`x' = south_R_`x' / deflator
	gen sur_S_`x' = south_S_`x' / deflator

	drop _merge deflator
	save "$Output\gdp_region_aux.dta", replace

use "$Output\auxx.dta", clear
merge 1:1 year nn ns sn ss using "$Output\gdp_region_aux.dta"
keep if _merge ==3 //The merge is by region, not country. Therefore _merge always equals 3, except if the year is not included in the main database. We are not dropping obs here.
drop _merge

*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j' //Note that the 1st year has trend==0.
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

*Creating log GDP by acq or tgt
gen n1_acq = (nn==1 | ns == 1)
gen s1_acq = (sn==1 | ss == 1)
gen n1_tgt = (nn==1 | sn == 1)
gen s1_tgt = (ns==1 | ss == 1)

* Assumption: GDP sender and receiver are equal

* test
gen gdp_avg = norte_S_`x'*norte_S_`x' if n1_acq == 1 & n1_tgt == 1
replace gdp_avg = sur_S_`x'*norte_S_`x' if s1_acq ==1 & n1_tgt == 1
replace gdp_avg = norte_S_`x'*sur_S_`x' if n1_acq ==1 & s1_tgt == 1
replace gdp_avg = sur_S_`x'*sur_S_`x' if s1_acq ==1 & s1_tgt == 1

* Generate N_value based of Portes and Rey
gen l_gdp_avg1 = log(sqrt(gdp_avg))
gen nn_value = l_value - l_gdp_avg1

*Regressions
*************
*1) Dependent Variable: Log(Value). Estimation method: OLS
reg nn_value  nn ns sn ss  nn_trend ns_trend sn_trend ss_trend, robust

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
			outreg2 nn_value using "$Output\T6_`x'.xls", ctitle("OLS R-R log(value)") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R") ///
				 keep(nn_trend ns_trend sn_trend ss_trend) bdec(3) excel replace
restore

*******************
*COUNTRY-REGION REG
*******************
*The data is already at the C-R level so no transformation is needed.
*In contrast to CPIS and FDI, we cannot obtain Region-Country values. So the regression is not Country-Region and Region-Country
		
		//Merging with Region GDPs
		merge m:1 year using "$Input\regions_gdp.dta"
		keep if _merge ==3
		drop _merge
		keep acq tgt year value gdp_acq n1_* s1_* north_S_`x' south_S_`x' 
		
		*Use Country GDPs for Countries and REGION GDPs for REGIONs
		gen gdp_tgt = .
		replace gdp_tgt = north_S_`x' if tgt =="North" & gdp_tgt ==.
		replace gdp_tgt = south_S_`x' if tgt =="South" & gdp_tgt ==.
		drop north_S_`x'  south_S_`x' 
		
*Deflating GDPs (given that I have already deflated the capital flows)
merge m:1 year using "$Input/PRICE_DEFLATOR.dta"
keep if _merge ==3
replace gdp_tgt  = gdp_tgt / deflator
drop _merge deflator
			
sort acq tgt year
order acq tgt year value gdp_acq gdp_tgt   

*Creating Region-Region Dummies
gen nn=0
gen ns=0
gen sn=0
gen ss=0
replace nn=1 if n1_acq ==1 & tgt =="North"
replace ns=1 if n1_acq ==1 & tgt =="South"
replace sn=1 if s1_acq ==1 & tgt =="North"
replace ss=1 if s1_acq ==1 & tgt =="South"		
			
*Creating Trend*Dummies
gen trend=0
    forval j=1 / `=scalar(total_years)' {   
	replace trend=`j' if year==`=scalar(first_year)'+`j'
	}	
gen nn_trend=nn*trend
gen ns_trend=ns*trend
gen sn_trend=sn*trend
gen ss_trend=ss*trend

*Creating Country-Region dummies
gen country_dyad = acq+"_"+tgt
egen group = group(country_dyad)  //Country_dyad refers to the Country-Region (or Region-Country) pair.
xtset group year

*Creating dependent variable
gen l_value = log(value)
gen ll_gdp_mult = log(sqrt(gdp_acq * gdp_tgt))

*New dependient variables
gen nn_value = l_value - ll_gdp_mult
gen n_value = (value/sqrt(gdp_acq * gdp_tgt))

*Regressions
************
*1) Dependent Variable: Log(Value). Estimation method: OLS
reghdfe nn_value  nn_trend ns_trend sn_trend ss_trend, absorb(country_dyad) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 nn_value  using "$Output\T6_`x'.xls", ctitle("OLS C-R log(value)") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-R R-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend) excel  
				 *We use the "keep" option because we don't want to export all the FE coefficients.

*2) Dependent Variable: Value. Estimation method: PPML, no FE
ppml n_value  nn ns sn ss  nn_trend ns_trend sn_trend ss_trend, cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 n_value  using "$Output\T6_`x'.xls", ctitle("PPML C-R value") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "R-R") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend) excel  
				 
*3) Dependent Variable: Value. Estimation method: PPML, with FE
//xtpqml estimates ppml with fixed-effects
ppmlhdfe n_value  nn_trend ns_trend sn_trend ss_trend, absorb(country_dyad) cluster(country_dyad)

            *Wald Test
			test ss_trend  =  nn_trend   
			local coef1= round(_b[ss_trend] - _b[nn_trend],0.001)
			local test1=r(p)
		    test sn_trend  =  nn_trend   
			local coef2= round(_b[sn_trend] - _b[nn_trend],0.001)
			local test2=r(p)
			test ns_trend  =  nn_trend  
			local coef3    =  round(_b[ns_trend] - _b[nn_trend],0.001)
			local test3    = r(p)
			test sn_trend  =  ns_trend   
			local coef4= round((_b[sn_trend] - _b[ns_trend]),0.001)
			local test4=r(p)			
			test ss_trend + ns_trend = nn_trend + sn_trend   //South as Receiver vs North as Receiver
			local coef5= round((_b[ss_trend]+_b[ns_trend] - _b[nn_trend] - _b[sn_trend])/2,0.001)
			local test5=r(p)				
			test ss_trend + sn_trend = nn_trend + ns_trend   //South as Sender vs North as Sender
			local coef6= round((_b[ss_trend] + _b[sn_trend] - _b[nn_trend] - _b[ns_trend])/2,0.001)
			local test6=r(p)
			forvalues h=1(1)6{
			if `test`h''<0.01{
			local star`h' "***"
			}
			if `test`h''>0.01 & `test`h''<0.05{
			local star`h' "**"
			}
			if `test`h''>0.05 & `test`h''<0.1{
			local star`h' "*"
			}
			if `test`h''>0.1 {
			local star`h' ""
			}
			}	
outreg2 n_value  using "$Output\T6_`x'.xls", ctitle("PPML FE C-R value") ///
                 addtext("SS-NN", `coef1'`star1', "SN-NN", `coef2'`star2', "NS-NN", `coef3'`star3', "SN-NS", `coef4'`star4',"Srec-Nrec", `coef5'`star5', "Ssen-Nsen", `coef6'`star6', "FE", "C-R R-C") bdec(3) /// 
				 cons keep(nn_trend ns_trend sn_trend ss_trend) excel  
				 
erase "$Output\auxx.dta"
erase "$Output\gdp_region_aux.dta"
}
