/* **********************************************************************************************************************************************************************************************
This do file generates the input for T9 - Extensive Margin - Old vs. New Connections

In particular, we calculate Investments/World GDP

We distinguish between old and new connections
- New links are defined as those investments attributable to connections that were zero or missing in the 1st year (2001)
- Old links are defined as those investments attributable to connections that were non-zero, non-missing in the 1st year (2001)
   
Note that we do not deflate prices, given that we will report ratios and not absolute values.	
********************************************************************************************************************************************************************************************** */
clear all
set more off

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear
egen first_year= min(year)
egen last_year=max(year)

*Identifying NEW and OLD connections (with respect to the 1st period)	
	gen year1=0
	replace year1=1 if value!=0 & value!=. & year==first_year
	bysort country_dyad: egen sample=max(year1)
	drop year1
	//If sample ==1, the connection is OLD (with respect to the 1st year).
	//If sample ==0, the connection is NEW.
	
*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

bysort year: egen World_value=sum(value)	
	
forvalues y=1(1)2{		
preserve
*Keeping only OLD Connections
if `y'==1{
keep if sample ==1
scalar Sample ="OldLinks"
}
*Keeping only NEW Connections
if `y'==2{
keep if sample ==0
scalar Sample ="NewLinks"
}

*Investments between regions by year
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1

collapse (min) World_value NN_value NS_value SN_value SS_value first_year last_year, by(year)

*Merging with GDP
merge 1:1 year using "$Input\regions_gdp.dta"
keep if _merge ==3 //The merge is by region, not country. Therefore _merge ==3, except if the year is not included in the main database. We are not dropping obs here.
drop _merge

* 1. Investment/World GDP
*************************
*We use world receivers GDP (instead of world senders GDP). All senders are also receivers in our sample. So, by using the GDP of all receivers we are considering the GDP of all countries that participate in a region's cross-border flows
gen NN_WorldGDP = NN_value / world_R_`x'
gen NS_WorldGDP = NS_value / world_R_`x'
gen SN_WorldGDP = SN_value / world_R_`x'
gen SS_WorldGDP = SS_value / world_R_`x'

**********************************
*Presenting the Results (averages)
**********************************
keep if year==first_year | year==last_year
keep year first_year NN_WorldGDP-SS_WorldGDP

order year, first

if `y'==2 { //For new connections, we only need last year
drop if year==first_year
}

drop first_year
export excel using "$Output\T9.xlsx", sheet(`x'_`=scalar(Sample)') sheetreplace firstrow(variables)
restore
}
}




